/*
 * This file is part of pyfreespace.
 *
 * Copyright (c) 2009 Hillcrest Laboratories, Inc.
 *
 * pyfreespace is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef FREESPACEMODULEASYNC_H_
#define FREESPACEMODULEASYNC_H_

#include "Python.h"
#include "freespace/freespace.h"
#include "freespacedeviceobject.h"

/**
 * User specified callbacks for send and receive events. These are python callable objects.
 */
static PyObject* pySendCallback_ = NULL;
static PyObject* pyReceiveCallback_ = NULL;

/**
 * The callbacks given to libfreespace. Used as an intermediary between libfreespace and python
 */
void sendCallback(FreespaceDeviceId id, void* cookie, int rc);
void receiveCallback(FreespaceDeviceId id, const uint8_t* message, int length, void* cookie, int rc);

/**
 * Callbacks given to libfreespace for fd add/removal
 */
void remove_pollfd(FreespaceFileHandleType fd);
void add_pollfd(FreespaceFileHandleType fd, short events);

/**
 * Callback given to libfreespace for hotplug events
 */
void hotplugCallback(enum freespace_hotplugEvent event, FreespaceDeviceId id, void* cookie);


/* ------------- Freespace module asynchronous methods ---------- */

static char fs_freespace_perform__doc__[] = "Call this to allow libfreespace to service its active file descriptors";
PyObject* fs_perform(PyObject *self /* Not used */, PyObject *args);

static char fs_set_fd_callbacks__doc__[] = "Set callback functions for when file descriptors need to be added or removed from the select/poll list";
PyObject* fs_set_fd_callbacks(PyObject *self /* Not used */, PyObject *args);

static char fs_sync_fds__doc__[] = "Call the file descriptor added callback function for each internal file descriptor that is in use. \n \
        This should be called after freespace_setFileDescriptorCallbacks so that the app can get in sync with the current active set. ";
PyObject* fs_sync_fds(PyObject *self /* Not used */, PyObject *args);

static char fs_getNextTimeout__doc__[] = "Get the next timeout for a call to select or poll";
PyObject* fs_get_next_timeout(PyObject* self /* Not used */, PyObject *args);

static char fs_set_hotplug_callback__doc__[] = "Set a callback for whenever a Freespace device gets added or removed from the system.";
PyObject* fs_set_hotplug_callback(PyObject* self /*Not used */, PyObject *args);


static char FreespaceDevice_set_receive_callback__doc__[] = "Register a callback frunction to handle receieved HID messages";
PyObject* fs_set_receive_callback(FreespaceDeviceObject *self, PyObject *args);


#endif /* FREESPACEMODULEASYNC_H_ */
