#!/usr/bin/env python


import math

class Vector2():
    def __init__(self, x, y):
        self.x = x
        self.y = y
        
    def copy(self):
        return Vector2(self.x, self.y)
        
    def dot(a, b):
        return (a.x*b.x) + (a.y*b.y)
        
    def __neg__(self):
        return Vector2(-self.x, -self.y);
        
    def __add__(self, other):
        return Vector2(self.x + other.x, self.y + other.y)
        
    def __sub__(self, other):
        return Vector2(self.x - other.x, self.y - other.y)
        
    def __mul__(self, factor):
        return Vector2(self.x*factor, self.y*factor)
        
    def scale(self, factor):
        self.x *= factor
        self.y *= factor
        
    def __repr__(self):
        return repr([self.x,self.y])
        
    def len(self):
        return math.sqrt(Vector2.dot(self, self))
        
    def normalize(self):
        l = self.len()
        if l == 0:
            return
        self.x /= l
        self.y /= l
        
    def reflect(self, other):
        """Reflect this vector across the other vector"""
        o = other.copy()
        o.normalize()
        oLen = Vector2.dot(self, o)
        o.normalize()
        o.scale(oLen)
        halfChange = o - self
        newDir = o + halfChange
        return newDir   


class Vector3():
    def __init__(self, x, y, z):
        self.x = x
        self.y = y
        self.z = z
        
    def copy(self):
        return Vector3(self.x, self.y, self.z)
        
    def dot(a, b):
        return (a.x*b.x) + (a.y*b.y) + (a.z*b.z)
        
    def len(self):
        return math.sqrt(Vector3.dot(self, self))
        
    def __neg__(self):
        return Vector3(-x, -y, -z);
        
    def __add__(self, other):
        return Vector3(self.x + other.x, self.y + other.y, self.z + other.z)
        
    def __sub__(self, other):
        return Vector3(self.x - other.x, self.y - other.y, self.z - other.z)
        
    def __mul__(self, factor):
        return Vector3(self.x*factor, self.y*factor, self.z*factor)
        
    def __repr__(self):
        return repr([self.x,self.y,self.z])
        
    def __len__(self):
        return len(self)
        
    def normalize(self):
        l = self.len()
        if l == 0:
            return
        self.x /= l
        self.y /= l
        self.z /= l
    
