#!/usr/bin/env python
#
# This file is part of pyfreespace.
#  
# Copyright (c) 2009, Hillcrest Laboratories, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
#     * Neither the name of the Hillcrest Laboratories, Inc. nor the names
#       of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written
#       permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
#
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import freespace

def runMain():
    freespace.init()
    devices = freespace.get_device_list()
    
    if len(devices) == 0:
        print "No devices found"
        return
    device = devices[0] # Finds and gets the freespace device

    device.open()
    
    dmc = freespace.DataMotionControl()
    dmc.enableBodyMotion = True
    
    device.sendmessage(dmc)
    
    device.flush()

    print "Opened device"
    while(True):
        try:
            s = device.readmessage(500)
            if s is not None:
                print s
        except KeyboardInterrupt:
            print("Closing down")
            break
    
    dmc.enableBodyMotion = False
    dmc.enableMouseMovement = True
    device.sendmessage(dmc)
    
    device.close()
    freespace.exit()

# ---------------------- Main! --------------------------------

if (__name__ == "__main__"):
    runMain()
