#!/usr/bin/env python
#
# This file is part of pyfreespace.
#  
# Copyright (c) 2009 Hillcrest Laboratories, Inc. 
# 
# pyfreespace is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

import sys
from distutils.core import setup, Extension
import os.path

plat = sys.platform

sourceFiles = ['freespacemodule.c', 'freespacemodulemessages.c', 'freespacemoduleasync.c', 'freespacedeviceobject.c']
dependencies = ['freespacemodulemessages.h', 'freespacemoduleasync.h', 'freespacedeviceobject.h']

extra_dist_files = ['COPYING', 'moduleMessagesGenerator.py', 'THANKS', 'TODO', 'pyexamples/*']


# Set up cross-platform module definitions
lib_dirs = []
rlib_dirs = []
inc_dirs = []
libs = []
defines = []
datafiles = []

if plat == 'win32':
    inc_dirs = ['../libfreespace/include']
    lib_dirs = ['../libfreespace/win32/vs2005/release','../libfreespace/win32/vs2008/release']
    libs = ['libfreespace']
    defines.append(('WIN32', None))
    if os.path.isfile('../libfreespace/win32/vs2008/release/libfreespace.dll'):
        datafiles.append(('Lib\site-packages', ['../libfreespace/win32/vs2008/release/libfreespace.dll']))
    elif os.path.isfile('../libfreespace/win32/vs2005/release/libfreespace.dll'):
        datafiles.append(('Lib\site-packages', ['../libfreespace/win32/vs2005/release/libfreespace.dll']))        
elif plat == 'darwin':
    #freespace installs into /usr/local by default, but w/ MacPorts (which was possibly used) it installs to /opt/local/
    inc_dirs = ['/usr/local/include', '/opt/local/include']
    lib_dirs = ['/usr/local/lib', '/opt/local/lib']
    rlib_dirs = ['/usr/local/lib', '/opt/local/lib']
    libs = ['freespace']
else:
    #freespace installs into /usr/local by default
    inc_dirs = ['/usr/local/include']
    lib_dirs = ['/usr/local/lib']
    rlib_dirs = ['/usr/local/lib']
    libs = ['freespace']


#Below we define the actual C Python Extension module
module1 = Extension('freespace', 
                    libraries = libs,                    
                    include_dirs = inc_dirs,
                    library_dirs = lib_dirs,
                    runtime_library_dirs = rlib_dirs,
                    define_macros = defines,
                    depends = dependencies,
                    sources = sourceFiles)


# The setup function builds/installs/distributes the actual module
setup (name = 'pyfreespace',
       version = '0.4',
       description = 'python extension module for libfreespace',
       author = 'Hillcrest Labs, Inc.',
       author_email = '',
       maintainer = 'J.T. Burgess',
       maintainer_email = 'jt.burgess@hillcrestlabs.com',
       url = 'http://libfreespace.hillcrestlabs.com/',
       long_description = '''python extension module for libfreespace''',
       license = 'GNU LGPL v2.1',
       data_files = datafiles,
       ext_modules = [module1])
