/*
 * This file is part of pyfreespace.
 * 
 * Copyright (c) 2009 Hillcrest Laboratories, Inc. 
 *
 * pyfreespace is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "Python.h"
#include "freespacemodulemessages.h"
#include "freespace/freespace_codecs.h"
#include "freespace/freespace_printers.h"
#include "structmember.h"


/* ----------------------------------------------------- */
/* Declarations for objects of type MouseMovement */
typedef struct {
    PyObject_HEAD
    
    struct freespace_MouseMovement message;
} MouseMovement;

static PyTypeObject MouseMovementType;


#define MouseMovement_Check(v)  ((v)->ob_type == &MouseMovementType)

static struct PyMemberDef MouseMovement_members[] = {
    {"button1", T_BOOL, offsetof(MouseMovement, message.button1), READONLY, "button1"},
    {"button2", T_BOOL, offsetof(MouseMovement, message.button2), READONLY, "button2"},
    {"button3", T_BOOL, offsetof(MouseMovement, message.button3), READONLY, "button3"},
    {"button4", T_BOOL, offsetof(MouseMovement, message.button4), READONLY, "button4"},
    {"button5", T_BOOL, offsetof(MouseMovement, message.button5), READONLY, "button5"},
    {"button6", T_BOOL, offsetof(MouseMovement, message.button6), READONLY, "button6"},
    {"button7", T_BOOL, offsetof(MouseMovement, message.button7), READONLY, "button7"},
    {"button8", T_BOOL, offsetof(MouseMovement, message.button8), READONLY, "button8"},
    {"deltaX", T_BYTE, offsetof(MouseMovement, message.deltaX), READONLY, "Changes in pointer location in dimensionless units. Positive moves pointer right."},
    {"deltaY", T_BYTE, offsetof(MouseMovement, message.deltaY), READONLY, "Changes in pointer location in dimensionless units. Positive moves pointer down."},
    {"deltaWheel", T_BYTE, offsetof(MouseMovement, message.deltaWheel), READONLY, "Reports scroll wheel motion in detents. Up is positive."},
    {NULL}  /* Sentinel */
};

static PyObject *
MouseMovement_str(MouseMovement * obj)
{
    char str[1024];
    freespace_printMouseMovementStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject MouseMovementType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.MouseMovement",      /*tp_name*/
    sizeof(MouseMovement),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)MouseMovement_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "DEPRECATED. This report implements a HID Mouse with 8 buttons and a scroll wheel",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    MouseMovement_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ConsumerControl */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ConsumerControl message;
} ConsumerControl;

static PyTypeObject ConsumerControlType;


#define ConsumerControl_Check(v)  ((v)->ob_type == &ConsumerControlType)

static struct PyMemberDef ConsumerControl_members[] = {
    {"usageID", T_UBYTE, offsetof(ConsumerControl, message.usageID), READONLY, "A 12-bit field that carries a consumer control usage code"},
    {"usageID11_8", T_UBYTE, offsetof(ConsumerControl, message.usageID11_8), READONLY, "usageID11_8"},
    {"numPad", T_UBYTE, offsetof(ConsumerControl, message.numPad), READONLY, "numPad"},
    {"functionButtons", T_UBYTE, offsetof(ConsumerControl, message.functionButtons), READONLY, "Indicates up to 255 button presses"},
    {NULL}  /* Sentinel */
};

static PyObject *
ConsumerControl_str(ConsumerControl * obj)
{
    char str[1024];
    freespace_printConsumerControlStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ConsumerControlType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ConsumerControl",      /*tp_name*/
    sizeof(ConsumerControl),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ConsumerControl_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "DEPRECATED: Indicates buttons that operate a consumer electronics product.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ConsumerControl_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type KeyboardReport */
typedef struct {
    PyObject_HEAD
    
    struct freespace_KeyboardReport message;
} KeyboardReport;

static PyTypeObject KeyboardReportType;


#define KeyboardReport_Check(v)  ((v)->ob_type == &KeyboardReportType)

static struct PyMemberDef KeyboardReport_members[] = {
    {"LCtrl", T_BOOL, offsetof(KeyboardReport, message.LCtrl), READONLY, "LCtrl"},
    {"LShift", T_BOOL, offsetof(KeyboardReport, message.LShift), READONLY, "LShift"},
    {"LAlt", T_BOOL, offsetof(KeyboardReport, message.LAlt), READONLY, "LAlt"},
    {"LGui", T_BOOL, offsetof(KeyboardReport, message.LGui), READONLY, "LGui"},
    {"RCtrl", T_BOOL, offsetof(KeyboardReport, message.RCtrl), READONLY, "RCtrl"},
    {"RShift", T_BOOL, offsetof(KeyboardReport, message.RShift), READONLY, "RShift"},
    {"RAlt", T_BOOL, offsetof(KeyboardReport, message.RAlt), READONLY, "RAlt"},
    {"RGui", T_BOOL, offsetof(KeyboardReport, message.RGui), READONLY, "RGui"},
    {"keyID", T_SHORT, offsetof(KeyboardReport, message.keyID), READONLY, "keyID"},
    {NULL}  /* Sentinel */
};

static PyObject *
KeyboardReport_str(KeyboardReport * obj)
{
    char str[1024];
    freespace_printKeyboardReportStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject KeyboardReportType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.KeyboardReport",      /*tp_name*/
    sizeof(KeyboardReport),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)KeyboardReport_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "DEPRECATED. Indicates buttons from a computer keyboard or keypad. Refer to the USB HID Usage Tables Document Keyboard Page for more information",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    KeyboardReport_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type CoprocessorOutReport */
typedef struct {
    PyObject_HEAD
    
    struct freespace_CoprocessorOutReport message;
} CoprocessorOutReport;

static PyTypeObject CoprocessorOutReportType;


#define CoprocessorOutReport_Check(v)  ((v)->ob_type == &CoprocessorOutReportType)

static struct PyMemberDef CoprocessorOutReport_members[] = {
    {"payloadLength", T_SHORT, offsetof(CoprocessorOutReport, message.payloadLength), 0, "payloadLength"},
    {NULL}  /* Sentinel */
};

static PyObject *
CoprocessorOutReport_str(CoprocessorOutReport * obj)
{
    char str[1024];
    freespace_printCoprocessorOutReportStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject CoprocessorOutReportType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.CoprocessorOutReport",      /*tp_name*/
    sizeof(CoprocessorOutReport),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)CoprocessorOutReport_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Reserved for passing message through from the Freespace coprocessor to the USB host.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    CoprocessorOutReport_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type CoprocessorInReport */
typedef struct {
    PyObject_HEAD
    
    struct freespace_CoprocessorInReport message;
} CoprocessorInReport;

static PyTypeObject CoprocessorInReportType;


#define CoprocessorInReport_Check(v)  ((v)->ob_type == &CoprocessorInReportType)

static struct PyMemberDef CoprocessorInReport_members[] = {
    {"payloadLength", T_UBYTE, offsetof(CoprocessorInReport, message.payloadLength), READONLY, "payloadLength"},
    {NULL}  /* Sentinel */
};

static PyObject *
CoprocessorInReport_str(CoprocessorInReport * obj)
{
    char str[1024];
    freespace_printCoprocessorInReportStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject CoprocessorInReportType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.CoprocessorInReport",      /*tp_name*/
    sizeof(CoprocessorInReport),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)CoprocessorInReport_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Reserved for proprietary diagnostics, testing, and debugging use.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    CoprocessorInReport_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type BatteryLevelRequest */
typedef struct {
    PyObject_HEAD

} BatteryLevelRequest;

static PyTypeObject BatteryLevelRequestType;


#define BatteryLevelRequest_Check(v)  ((v)->ob_type == &BatteryLevelRequestType)

static PyTypeObject BatteryLevelRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.BatteryLevelRequest",      /*tp_name*/
    sizeof(BatteryLevelRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Sent by the host to request the battery status of the handheld unit.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type BatteryLevel */
typedef struct {
    PyObject_HEAD
    
    struct freespace_BatteryLevel message;
} BatteryLevel;

static PyTypeObject BatteryLevelType;


#define BatteryLevel_Check(v)  ((v)->ob_type == &BatteryLevelType)

static struct PyMemberDef BatteryLevel_members[] = {
    {"batteryStrength", T_UBYTE, offsetof(BatteryLevel, message.batteryStrength), READONLY, "A percentage of the operating voltage range (0-100%)"},
    {NULL}  /* Sentinel */
};

static PyObject *
BatteryLevel_str(BatteryLevel * obj)
{
    char str[1024];
    freespace_printBatteryLevelStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject BatteryLevelType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.BatteryLevel",      /*tp_name*/
    sizeof(BatteryLevel),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)BatteryLevel_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Indicates the battery strength of the handheld unit.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    BatteryLevel_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type BodyFrame */
typedef struct {
    PyObject_HEAD
    
    struct freespace_BodyFrame message;
} BodyFrame;

static PyTypeObject BodyFrameType;


#define BodyFrame_Check(v)  ((v)->ob_type == &BodyFrameType)

static struct PyMemberDef BodyFrame_members[] = {
    {"button1", T_BOOL, offsetof(BodyFrame, message.button1), READONLY, "button1"},
    {"button2", T_BOOL, offsetof(BodyFrame, message.button2), READONLY, "button2"},
    {"button3", T_BOOL, offsetof(BodyFrame, message.button3), READONLY, "button3"},
    {"button4", T_BOOL, offsetof(BodyFrame, message.button4), READONLY, "button4"},
    {"button5", T_BOOL, offsetof(BodyFrame, message.button5), READONLY, "button5"},
    {"deltaX", T_BYTE, offsetof(BodyFrame, message.deltaX), READONLY, "deltaX"},
    {"deltaY", T_BYTE, offsetof(BodyFrame, message.deltaY), READONLY, "deltaY"},
    {"deltaWheel", T_BYTE, offsetof(BodyFrame, message.deltaWheel), READONLY, "deltaWheel"},
    {"sequenceNumber", T_UINT, offsetof(BodyFrame, message.sequenceNumber), READONLY, "A monotonically increasing integer generated by the Freespace sensor board at a nominal rate of 125 Hz.	Can be used to correlate body frame messages with the user frame messages"},
    {"linearAccelX", T_SHORT, offsetof(BodyFrame, message.linearAccelX), READONLY, "Linear Acceleration is reported in SI units (cm/s^2) with an exponent of -1. X is positive forward. Y is positive right. Z is positive down wrt handheld frame of reference."},
    {"linearAccelY", T_SHORT, offsetof(BodyFrame, message.linearAccelY), READONLY, "linearAccelY"},
    {"linearAccelZ", T_SHORT, offsetof(BodyFrame, message.linearAccelZ), READONLY, "linearAccelZ"},
    {"angularVelX", T_SHORT, offsetof(BodyFrame, message.angularVelX), READONLY, "Angular Velocity is reported in units of rad/s with an exponent of -3. X positive is tilt right(roll). Y positive it tilt up(pitch). Z positive is turn right(yaw) wrt the handheld device frame of reference."},
    {"angularVelY", T_SHORT, offsetof(BodyFrame, message.angularVelY), READONLY, "angularVelY"},
    {"angularVelZ", T_SHORT, offsetof(BodyFrame, message.angularVelZ), READONLY, "angularVelZ"},
    {NULL}  /* Sentinel */
};

static PyObject *
BodyFrame_str(BodyFrame * obj)
{
    char str[1024];
    freespace_printBodyFrameStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject BodyFrameType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.BodyFrame",      /*tp_name*/
    sizeof(BodyFrame),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)BodyFrame_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Conveys the motion relative to the body frame of the Freespace handheld device.   The data have been processed to remove tremor and other unwanted side effects.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    BodyFrame_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type UserFrame */
typedef struct {
    PyObject_HEAD
    
    struct freespace_UserFrame message;
} UserFrame;

static PyTypeObject UserFrameType;


#define UserFrame_Check(v)  ((v)->ob_type == &UserFrameType)

static struct PyMemberDef UserFrame_members[] = {
    {"button1", T_BOOL, offsetof(UserFrame, message.button1), READONLY, "button1"},
    {"button2", T_BOOL, offsetof(UserFrame, message.button2), READONLY, "button2"},
    {"button3", T_BOOL, offsetof(UserFrame, message.button3), READONLY, "button3"},
    {"button4", T_BOOL, offsetof(UserFrame, message.button4), READONLY, "button4"},
    {"button5", T_BOOL, offsetof(UserFrame, message.button5), READONLY, "button5"},
    {"deltaX", T_BYTE, offsetof(UserFrame, message.deltaX), READONLY, "deltaX"},
    {"deltaY", T_BYTE, offsetof(UserFrame, message.deltaY), READONLY, "deltaY"},
    {"deltaWheel", T_BYTE, offsetof(UserFrame, message.deltaWheel), READONLY, "deltaWheel"},
    {"sequenceNumber", T_UINT, offsetof(UserFrame, message.sequenceNumber), READONLY, "Correlates the position report with the Body Frame Motion Report"},
    {"linearPosX", T_SHORT, offsetof(UserFrame, message.linearPosX), READONLY, "Linear Offset is in units of meters. X positive is right. Y positive is near. Z positive is down wrt the user frame of reference."},
    {"linearPosY", T_SHORT, offsetof(UserFrame, message.linearPosY), READONLY, "linearPosY"},
    {"linearPosZ", T_SHORT, offsetof(UserFrame, message.linearPosZ), READONLY, "linearPosZ"},
    {"angularPosA", T_SHORT, offsetof(UserFrame, message.angularPosA), READONLY, "Angular Position is in dimensionless units. The axes are given in quaternion form where A, B, C, D represent the real, i, j, and k coefficients."},
    {"angularPosB", T_SHORT, offsetof(UserFrame, message.angularPosB), READONLY, "angularPosB"},
    {"angularPosC", T_SHORT, offsetof(UserFrame, message.angularPosC), READONLY, "angularPosC"},
    {"angularPosD", T_SHORT, offsetof(UserFrame, message.angularPosD), READONLY, "angularPosD"},
    {NULL}  /* Sentinel */
};

static PyObject *
UserFrame_str(UserFrame * obj)
{
    char str[1024];
    freespace_printUserFrameStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject UserFrameType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.UserFrame",      /*tp_name*/
    sizeof(UserFrame),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)UserFrame_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Conveys the handheld device position and orientation with respect to a user frame of reference.  The gravity acceleration vector points up along the negative Z  axis.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    UserFrame_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type DataMotionControl */
typedef struct {
    PyObject_HEAD
    
    struct freespace_DataMotionControl message;
} DataMotionControl;

static PyTypeObject DataMotionControlType;


#define DataMotionControl_Check(v)  ((v)->ob_type == &DataMotionControlType)

static struct PyMemberDef DataMotionControl_members[] = {
    {"enableBodyMotion", T_BOOL, offsetof(DataMotionControl, message.enableBodyMotion), 0, "Enable Body Motion: when set to 1 enables Body Frame Motion reports."},
    {"enableUserPosition", T_BOOL, offsetof(DataMotionControl, message.enableUserPosition), 0, "Enable User Position: when set to 1 enables User Frame Position reports"},
    {"inhibitPowerManager", T_BOOL, offsetof(DataMotionControl, message.inhibitPowerManager), 0, "Inhibit Power Manager: when set to 1 disables the power management feature that automatically stops sending motion reports after a period of no motion."},
    {"enableMouseMovement", T_BOOL, offsetof(DataMotionControl, message.enableMouseMovement), 0, "Enable Mouse Movement: when set to 1 enables Mouse Movement reports."},
    {"disableFreespace", T_BOOL, offsetof(DataMotionControl, message.disableFreespace), 0, "Disable Freespace: when set to 1 disables the Freespace motion sensing system to conserve power. No pointer or motion reports are sent regardless of the value of the other bits."},
    {NULL}  /* Sentinel */
};

static PyObject *
DataMotionControl_str(DataMotionControl * obj)
{
    char str[1024];
    freespace_printDataMotionControlStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject DataMotionControlType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.DataMotionControl",      /*tp_name*/
    sizeof(DataMotionControl),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)DataMotionControl_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This report controls the behavior of the Freespace motion reports. The unused bits are reserved for future features.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    DataMotionControl_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ConfigurationMessage */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ConfigurationMessage message;
} ConfigurationMessage;

static PyTypeObject ConfigurationMessageType;


#define ConfigurationMessage_Check(v)  ((v)->ob_type == &ConfigurationMessageType)

static struct PyMemberDef ConfigurationMessage_members[] = {
    {"SDA", T_SHORT, offsetof(ConfigurationMessage, message.SDA), 0, "SDA(1)/NORMAL(0)"},
    {NULL}  /* Sentinel */
};

static PyObject *
ConfigurationMessage_str(ConfigurationMessage * obj)
{
    char str[1024];
    freespace_printConfigurationMessageStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ConfigurationMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ConfigurationMessage",      /*tp_name*/
    sizeof(ConfigurationMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ConfigurationMessage_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ConfigurationMessage_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type PairingMessage */
typedef struct {
    PyObject_HEAD

} PairingMessage;

static PyTypeObject PairingMessageType;


#define PairingMessage_Check(v)  ((v)->ob_type == &PairingMessageType)

static PyTypeObject PairingMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.PairingMessage",      /*tp_name*/
    sizeof(PairingMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Used by the host to put the dongle into normal pairing mode.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type DebugMessage */
typedef struct {
    PyObject_HEAD

} DebugMessage;

static PyTypeObject DebugMessageType;


#define DebugMessage_Check(v)  ((v)->ob_type == &DebugMessageType)

static PyTypeObject DebugMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.DebugMessage",      /*tp_name*/
    sizeof(DebugMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Used for debug messages.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FactoryCalibrationReadRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FactoryCalibrationReadRequest message;
} FactoryCalibrationReadRequest;

static PyTypeObject FactoryCalibrationReadRequestType;


#define FactoryCalibrationReadRequest_Check(v)  ((v)->ob_type == &FactoryCalibrationReadRequestType)

static struct PyMemberDef FactoryCalibrationReadRequest_members[] = {
    {"wordOffsetRequested", T_UBYTE, offsetof(FactoryCalibrationReadRequest, message.wordOffsetRequested), 0, "wordOffsetRequested"},
    {NULL}  /* Sentinel */
};

static PyObject *
FactoryCalibrationReadRequest_str(FactoryCalibrationReadRequest * obj)
{
    char str[1024];
    freespace_printFactoryCalibrationReadRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FactoryCalibrationReadRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FactoryCalibrationReadRequest",      /*tp_name*/
    sizeof(FactoryCalibrationReadRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FactoryCalibrationReadRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from dongle towards the loop to request a chunk of cal data to be sent. This is used in the Zebra system architecture.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FactoryCalibrationReadRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type DongleReset */
typedef struct {
    PyObject_HEAD
    
    struct freespace_DongleReset message;
} DongleReset;

static PyTypeObject DongleResetType;


#define DongleReset_Check(v)  ((v)->ob_type == &DongleResetType)

static struct PyMemberDef DongleReset_members[] = {
    {"loaderKey", T_UINT, offsetof(DongleReset, message.loaderKey), 0, "loaderKey"},
    {NULL}  /* Sentinel */
};

static PyObject *
DongleReset_str(DongleReset * obj)
{
    char str[1024];
    freespace_printDongleResetStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject DongleResetType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.DongleReset",      /*tp_name*/
    sizeof(DongleReset),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)DongleReset_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from host to dongle to trigger a reset into the bootloader. The 32-bit loaderkey value is placed at a special location in RAM and the system is reset. If the loader key has the proper value, the bootloader will then take control. Otherwise the bootloader will transfer control to the application immediately.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    DongleReset_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FTDongleStatusRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FTDongleStatusRequest message;
} FTDongleStatusRequest;

static PyTypeObject FTDongleStatusRequestType;


#define FTDongleStatusRequest_Check(v)  ((v)->ob_type == &FTDongleStatusRequestType)

static struct PyMemberDef FTDongleStatusRequest_members[] = {
    {"power", T_BOOL, offsetof(FTDongleStatusRequest, message.power), 0, "Power:	 0:disable DUT power	 1:enable DUT power"},
    {"reset", T_BOOL, offsetof(FTDongleStatusRequest, message.reset), 0, "Reset:	 0:deassert DUT reset signal	 1:assert DUT reset signal"},
    {"presence", T_BOOL, offsetof(FTDongleStatusRequest, message.presence), 0, "Presence:	 0:deassert presence signal	 1:assert presence signal"},
    {"operation", T_BOOL, offsetof(FTDongleStatusRequest, message.operation), 0, "Operation:	 0:read status. Values for presence, reset, and power are don't cares	 1: update status. Status is set to values indicated by presence, power, and reset"},
    {NULL}  /* Sentinel */
};

static PyObject *
FTDongleStatusRequest_str(FTDongleStatusRequest * obj)
{
    char str[1024];
    freespace_printFTDongleStatusRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FTDongleStatusRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FTDongleStatusRequest",      /*tp_name*/
    sizeof(FTDongleStatusRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FTDongleStatusRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the host towards the FT dongle to update or request the current status of the dongle",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FTDongleStatusRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type StatisticsRequest */
typedef struct {
    PyObject_HEAD

} StatisticsRequest;

static PyTypeObject StatisticsRequestType;


#define StatisticsRequest_Check(v)  ((v)->ob_type == &StatisticsRequestType)

static PyTypeObject StatisticsRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.StatisticsRequest",      /*tp_name*/
    sizeof(StatisticsRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the host towards the loop to request a statistics report.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ZebraSystemTest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ZebraSystemTest message;
} ZebraSystemTest;

static PyTypeObject ZebraSystemTestType;


#define ZebraSystemTest_Check(v)  ((v)->ob_type == &ZebraSystemTestType)

static struct PyMemberDef ZebraSystemTest_members[] = {
    {"reset", T_BOOL, offsetof(ZebraSystemTest, message.reset), 0, "1 to reset, 0 for normal"},
    {"mode", T_BOOL, offsetof(ZebraSystemTest, message.mode), 0, "0: RF+USB, 1: USB"},
    {"pcSequence", T_SHORT, offsetof(ZebraSystemTest, message.pcSequence), 0, "pcSequence"},
    {NULL}  /* Sentinel */
};

static PyObject *
ZebraSystemTest_str(ZebraSystemTest * obj)
{
    char str[1024];
    freespace_printZebraSystemTestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ZebraSystemTestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ZebraSystemTest",      /*tp_name*/
    sizeof(ZebraSystemTest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ZebraSystemTest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is used during Zebra Sytem test to collect link (RF+USB) strength statistics.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ZebraSystemTest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ProductIDRequest */
typedef struct {
    PyObject_HEAD

} ProductIDRequest;

static PyTypeObject ProductIDRequestType;


#define ProductIDRequest_Check(v)  ((v)->ob_type == &ProductIDRequestType)

static PyTypeObject ProductIDRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ProductIDRequest",      /*tp_name*/
    sizeof(ProductIDRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the host to the attached device(dongle) to request the product ID information. The dongle will forward this request to the Loop.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type LoopLEDSetRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_LoopLEDSetRequest message;
} LoopLEDSetRequest;

static PyTypeObject LoopLEDSetRequestType;


#define LoopLEDSetRequest_Check(v)  ((v)->ob_type == &LoopLEDSetRequestType)

static struct PyMemberDef LoopLEDSetRequest_members[] = {
    {"onOff", T_UBYTE, offsetof(LoopLEDSetRequest, message.onOff), 0, "0: Off, 1: On"},
    {"selectLED", T_UBYTE, offsetof(LoopLEDSetRequest, message.selectLED), 0, "LED Select: 0-green(all devices)	 1-red(all devices)	 2-yellow(all devices)	 3-blue(all devices)	 4-FTA green	 5-FTA red	 6-S2U yellow	 7-S2U blue	 8-Dominion LED PWM	 9-Dominion LED1	 10-Dominion LED2"},
    {NULL}  /* Sentinel */
};

static PyObject *
LoopLEDSetRequest_str(LoopLEDSetRequest * obj)
{
    char str[1024];
    freespace_printLoopLEDSetRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject LoopLEDSetRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.LoopLEDSetRequest",      /*tp_name*/
    sizeof(LoopLEDSetRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)LoopLEDSetRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This request causes the Loop to set a status LED to a particular value",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    LoopLEDSetRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type AlwaysOnRequest */
typedef struct {
    PyObject_HEAD

} AlwaysOnRequest;

static PyTypeObject AlwaysOnRequestType;


#define AlwaysOnRequest_Check(v)  ((v)->ob_type == &AlwaysOnRequestType)

static PyTypeObject AlwaysOnRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.AlwaysOnRequest",      /*tp_name*/
    sizeof(AlwaysOnRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message forces the Loop into an always on state. It is relayed to the Loop from the dongle.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FrequencyFixRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FrequencyFixRequest message;
} FrequencyFixRequest;

static PyTypeObject FrequencyFixRequestType;


#define FrequencyFixRequest_Check(v)  ((v)->ob_type == &FrequencyFixRequestType)

static struct PyMemberDef FrequencyFixRequest_members[] = {
    {"channel0", T_UBYTE, offsetof(FrequencyFixRequest, message.channel0), 0, "channel0"},
    {"channel1", T_UBYTE, offsetof(FrequencyFixRequest, message.channel1), 0, "channel1"},
    {"channel2", T_UBYTE, offsetof(FrequencyFixRequest, message.channel2), 0, "channel2"},
    {"channel3", T_UBYTE, offsetof(FrequencyFixRequest, message.channel3), 0, "channel3"},
    {"channel4", T_UBYTE, offsetof(FrequencyFixRequest, message.channel4), 0, "channel4"},
    {"device", T_UBYTE, offsetof(FrequencyFixRequest, message.device), 0, "1 for dongle, 2 for loop"},
    {NULL}  /* Sentinel */
};

static PyObject *
FrequencyFixRequest_str(FrequencyFixRequest * obj)
{
    char str[1024];
    freespace_printFrequencyFixRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FrequencyFixRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FrequencyFixRequest",      /*tp_name*/
    sizeof(FrequencyFixRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FrequencyFixRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message causes the FR frequencies of the selected device to be fixed at channels 0-4. The last byte selects the device. 	 When the loop is selected it is put into a mode where it does not require the dongle to transmit and where it does not go to sleep.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FrequencyFixRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type SoftwareResetMessage */
typedef struct {
    PyObject_HEAD
    
    struct freespace_SoftwareResetMessage message;
} SoftwareResetMessage;

static PyTypeObject SoftwareResetMessageType;


#define SoftwareResetMessage_Check(v)  ((v)->ob_type == &SoftwareResetMessageType)

static struct PyMemberDef SoftwareResetMessage_members[] = {
    {"device", T_UBYTE, offsetof(SoftwareResetMessage, message.device), 0, "1 for dongle"},
    {NULL}  /* Sentinel */
};

static PyObject *
SoftwareResetMessage_str(SoftwareResetMessage * obj)
{
    char str[1024];
    freespace_printSoftwareResetMessageStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject SoftwareResetMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.SoftwareResetMessage",      /*tp_name*/
    sizeof(SoftwareResetMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)SoftwareResetMessage_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message software resets the selected device.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    SoftwareResetMessage_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type DongleRFDisableMessage */
typedef struct {
    PyObject_HEAD

} DongleRFDisableMessage;

static PyTypeObject DongleRFDisableMessageType;


#define DongleRFDisableMessage_Check(v)  ((v)->ob_type == &DongleRFDisableMessageType)

static PyTypeObject DongleRFDisableMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.DongleRFDisableMessage",      /*tp_name*/
    sizeof(DongleRFDisableMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message disables the RF on the dongle. The RF is disabled until the next soft/hard reset.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type DongleRFSupressHomeFrequencyMessage */
typedef struct {
    PyObject_HEAD
    
    struct freespace_DongleRFSupressHomeFrequencyMessage message;
} DongleRFSupressHomeFrequencyMessage;

static PyTypeObject DongleRFSupressHomeFrequencyMessageType;


#define DongleRFSupressHomeFrequencyMessage_Check(v)  ((v)->ob_type == &DongleRFSupressHomeFrequencyMessageType)

static struct PyMemberDef DongleRFSupressHomeFrequencyMessage_members[] = {
    {"low", T_UBYTE, offsetof(DongleRFSupressHomeFrequencyMessage, message.low), 0, "low"},
    {"high", T_UBYTE, offsetof(DongleRFSupressHomeFrequencyMessage, message.high), 0, "high"},
    {NULL}  /* Sentinel */
};

static PyObject *
DongleRFSupressHomeFrequencyMessage_str(DongleRFSupressHomeFrequencyMessage * obj)
{
    char str[1024];
    freespace_printDongleRFSupressHomeFrequencyMessageStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject DongleRFSupressHomeFrequencyMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.DongleRFSupressHomeFrequencyMessage",      /*tp_name*/
    sizeof(DongleRFSupressHomeFrequencyMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)DongleRFSupressHomeFrequencyMessage_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is for RF Home frequency supression on the dongle.  	802.11 defines the peak of a channel to cover the range +-11MHz from the center frequency of the channel. 	Hillcrest adds an extra 1MHz to this boundary, so Low and High should be -12MHz from the center channel of the 802.11 	and +12MHz from the center channel of 802.11 respectively. These values must be in the range [1,82]. 	To disable home frequency suppression, set either Low or High to be out-of-range. 0xFF is the preferred value for disabling suppression.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    DongleRFSupressHomeFrequencyMessage_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type SPIOperationMessage */
typedef struct {
    PyObject_HEAD
    
    struct freespace_SPIOperationMessage message;
} SPIOperationMessage;

static PyTypeObject SPIOperationMessageType;


#define SPIOperationMessage_Check(v)  ((v)->ob_type == &SPIOperationMessageType)

static struct PyMemberDef SPIOperationMessage_members[] = {
    {"byte0", T_UBYTE, offsetof(SPIOperationMessage, message.byte0), 0, "byte0"},
    {"byte1", T_UBYTE, offsetof(SPIOperationMessage, message.byte1), 0, "byte1"},
    {"byte2", T_UBYTE, offsetof(SPIOperationMessage, message.byte2), 0, "byte2"},
    {"byte3", T_UBYTE, offsetof(SPIOperationMessage, message.byte3), 0, "byte3"},
    {"byte4", T_UBYTE, offsetof(SPIOperationMessage, message.byte4), 0, "byte4"},
    {"byte5", T_UBYTE, offsetof(SPIOperationMessage, message.byte5), 0, "byte5"},
    {NULL}  /* Sentinel */
};

static PyObject *
SPIOperationMessage_str(SPIOperationMessage * obj)
{
    char str[1024];
    freespace_printSPIOperationMessageStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject SPIOperationMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.SPIOperationMessage",      /*tp_name*/
    sizeof(SPIOperationMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)SPIOperationMessage_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message carries a generic SPI operation to be sent to a test module, such as FSRK-E. 	The SPI response message is sent back to the host.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    SPIOperationMessage_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type EventReportConfigSetRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_EventReportConfigSetRequest message;
} EventReportConfigSetRequest;

static PyTypeObject EventReportConfigSetRequestType;


#define EventReportConfigSetRequest_Check(v)  ((v)->ob_type == &EventReportConfigSetRequestType)

static struct PyMemberDef EventReportConfigSetRequest_members[] = {
    {"intc", T_BOOL, offsetof(EventReportConfigSetRequest, message.intc), 0, "Summary interrupt detected."},
    {"xyMov", T_BOOL, offsetof(EventReportConfigSetRequest, message.xyMov), 0, "X-Y pointer movement data ready."},
    {"acSt", T_BOOL, offsetof(EventReportConfigSetRequest, message.acSt), 0, "Activity classification status change"},
    {"reset", T_BOOL, offsetof(EventReportConfigSetRequest, message.reset), 0, "Test module reset detected."},
    {"motDr", T_BOOL, offsetof(EventReportConfigSetRequest, message.motDr), 0, "Motion data ready"},
    {"wom", T_BOOL, offsetof(EventReportConfigSetRequest, message.wom), 0, "Wake-on-motion detected."},
    {"motOv", T_BOOL, offsetof(EventReportConfigSetRequest, message.motOv), 0, "Motion data overflow"},
    {"acEv", T_BOOL, offsetof(EventReportConfigSetRequest, message.acEv), 0, "Activity classification event detected."},
    {"sdaDr", T_BOOL, offsetof(EventReportConfigSetRequest, message.sdaDr), 0, "SDA data ready."},
    {"sdaOv", T_BOOL, offsetof(EventReportConfigSetRequest, message.sdaOv), 0, "SDA data overflow."},
    {"cfgSt", T_BOOL, offsetof(EventReportConfigSetRequest, message.cfgSt), 0, "Configuration StatusChange"},
    {NULL}  /* Sentinel */
};

static PyObject *
EventReportConfigSetRequest_str(EventReportConfigSetRequest * obj)
{
    char str[1024];
    freespace_printEventReportConfigSetRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject EventReportConfigSetRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.EventReportConfigSetRequest",      /*tp_name*/
    sizeof(EventReportConfigSetRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)EventReportConfigSetRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from the host to an FSRK-E adapter test module, 	 to configure which events will cause the test module to send an event report message to the host. 	 A bit set to one indicates the reporting for that event is enabled.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    EventReportConfigSetRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type EventReportConfigGetRequest */
typedef struct {
    PyObject_HEAD

} EventReportConfigGetRequest;

static PyTypeObject EventReportConfigGetRequestType;


#define EventReportConfigGetRequest_Check(v)  ((v)->ob_type == &EventReportConfigGetRequestType)

static PyTypeObject EventReportConfigGetRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.EventReportConfigGetRequest",      /*tp_name*/
    sizeof(EventReportConfigGetRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from the host to an FSRK-E adapter test module to request the current configuration for event reports.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type UnknownCRSNotification */
typedef struct {
    PyObject_HEAD
    
    struct freespace_UnknownCRSNotification message;
} UnknownCRSNotification;

static PyTypeObject UnknownCRSNotificationType;


#define UnknownCRSNotification_Check(v)  ((v)->ob_type == &UnknownCRSNotificationType)

static struct PyMemberDef UnknownCRSNotification_members[] = {
    {"unknownReportID", T_UBYTE, offsetof(UnknownCRSNotification, message.unknownReportID), 0, "This is the HID report ID of the unknown message received by the base station."},
    {"unknownSubMessageID", T_UBYTE, offsetof(UnknownCRSNotification, message.unknownSubMessageID), 0, "This is the HID sub-message ID of the unknown message received by the base station."},
    {NULL}  /* Sentinel */
};

static PyObject *
UnknownCRSNotification_str(UnknownCRSNotification * obj)
{
    char str[1024];
    freespace_printUnknownCRSNotificationStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject UnknownCRSNotificationType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.UnknownCRSNotification",      /*tp_name*/
    sizeof(UnknownCRSNotification),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)UnknownCRSNotification_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from a base station handheld. It indicates that the base station did not 	 recognize a CRS message that the handheld had sent. This message will never be sent over USB.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    UnknownCRSNotification_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSLoopReadRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSLoopReadRequest message;
} FRSLoopReadRequest;

static PyTypeObject FRSLoopReadRequestType;


#define FRSLoopReadRequest_Check(v)  ((v)->ob_type == &FRSLoopReadRequestType)

static struct PyMemberDef FRSLoopReadRequest_members[] = {
    {"wordOffset", T_SHORT, offsetof(FRSLoopReadRequest, message.wordOffset), 0, "wordOffset"},
    {"FRStype", T_SHORT, offsetof(FRSLoopReadRequest, message.FRStype), 0, "FRStype"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSLoopReadRequest_str(FRSLoopReadRequest * obj)
{
    char str[1024];
    freespace_printFRSLoopReadRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSLoopReadRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSLoopReadRequest",      /*tp_name*/
    sizeof(FRSLoopReadRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSLoopReadRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from dongle towards the loop to request flash record to be sent. 	The data sent starts from the word offset and continues through to the end of the record.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSLoopReadRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSLoopWriteRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSLoopWriteRequest message;
} FRSLoopWriteRequest;

static PyTypeObject FRSLoopWriteRequestType;


#define FRSLoopWriteRequest_Check(v)  ((v)->ob_type == &FRSLoopWriteRequestType)

static struct PyMemberDef FRSLoopWriteRequest_members[] = {
    {"length", T_SHORT, offsetof(FRSLoopWriteRequest, message.length), 0, "length"},
    {"FRStype", T_SHORT, offsetof(FRSLoopWriteRequest, message.FRStype), 0, "FRStype"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSLoopWriteRequest_str(FRSLoopWriteRequest * obj)
{
    char str[1024];
    freespace_printFRSLoopWriteRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSLoopWriteRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSLoopWriteRequest",      /*tp_name*/
    sizeof(FRSLoopWriteRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSLoopWriteRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the host towards the loop to initiate a flash record write. 	A length of 0 will cause the record to be invalidated.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSLoopWriteRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSLoopWriteData */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSLoopWriteData message;
} FRSLoopWriteData;

static PyTypeObject FRSLoopWriteDataType;


#define FRSLoopWriteData_Check(v)  ((v)->ob_type == &FRSLoopWriteDataType)

static struct PyMemberDef FRSLoopWriteData_members[] = {
    {"wordOffset", T_SHORT, offsetof(FRSLoopWriteData, message.wordOffset), 0, "wordOffset"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSLoopWriteData_str(FRSLoopWriteData * obj)
{
    char str[1024];
    freespace_printFRSLoopWriteDataStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSLoopWriteDataType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSLoopWriteData",      /*tp_name*/
    sizeof(FRSLoopWriteData),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSLoopWriteData_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from the host towards the loop to write data to the record a previous write request indicated.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSLoopWriteData_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSDongleReadRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSDongleReadRequest message;
} FRSDongleReadRequest;

static PyTypeObject FRSDongleReadRequestType;


#define FRSDongleReadRequest_Check(v)  ((v)->ob_type == &FRSDongleReadRequestType)

static struct PyMemberDef FRSDongleReadRequest_members[] = {
    {"wordOffset", T_SHORT, offsetof(FRSDongleReadRequest, message.wordOffset), 0, "wordOffset"},
    {"FRStype", T_SHORT, offsetof(FRSDongleReadRequest, message.FRStype), 0, "FRStype"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSDongleReadRequest_str(FRSDongleReadRequest * obj)
{
    char str[1024];
    freespace_printFRSDongleReadRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSDongleReadRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSDongleReadRequest",      /*tp_name*/
    sizeof(FRSDongleReadRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSDongleReadRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSDongleReadRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSDongleWriteRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSDongleWriteRequest message;
} FRSDongleWriteRequest;

static PyTypeObject FRSDongleWriteRequestType;


#define FRSDongleWriteRequest_Check(v)  ((v)->ob_type == &FRSDongleWriteRequestType)

static struct PyMemberDef FRSDongleWriteRequest_members[] = {
    {"length", T_SHORT, offsetof(FRSDongleWriteRequest, message.length), 0, "length"},
    {"FRStype", T_SHORT, offsetof(FRSDongleWriteRequest, message.FRStype), 0, "FRStype"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSDongleWriteRequest_str(FRSDongleWriteRequest * obj)
{
    char str[1024];
    freespace_printFRSDongleWriteRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSDongleWriteRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSDongleWriteRequest",      /*tp_name*/
    sizeof(FRSDongleWriteRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSDongleWriteRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSDongleWriteRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSDongleWriteData */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSDongleWriteData message;
} FRSDongleWriteData;

static PyTypeObject FRSDongleWriteDataType;


#define FRSDongleWriteData_Check(v)  ((v)->ob_type == &FRSDongleWriteDataType)

static struct PyMemberDef FRSDongleWriteData_members[] = {
    {"wordOffset", T_SHORT, offsetof(FRSDongleWriteData, message.wordOffset), 0, "wordOffset"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSDongleWriteData_str(FRSDongleWriteData * obj)
{
    char str[1024];
    freespace_printFRSDongleWriteDataStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSDongleWriteDataType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSDongleWriteData",      /*tp_name*/
    sizeof(FRSDongleWriteData),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSDongleWriteData_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSDongleWriteData_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSEFlashReadRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSEFlashReadRequest message;
} FRSEFlashReadRequest;

static PyTypeObject FRSEFlashReadRequestType;


#define FRSEFlashReadRequest_Check(v)  ((v)->ob_type == &FRSEFlashReadRequestType)

static struct PyMemberDef FRSEFlashReadRequest_members[] = {
    {"wordOffset", T_SHORT, offsetof(FRSEFlashReadRequest, message.wordOffset), 0, "wordOffset"},
    {"FRStype", T_SHORT, offsetof(FRSEFlashReadRequest, message.FRStype), 0, "FRStype"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSEFlashReadRequest_str(FRSEFlashReadRequest * obj)
{
    char str[1024];
    freespace_printFRSEFlashReadRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSEFlashReadRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSEFlashReadRequest",      /*tp_name*/
    sizeof(FRSEFlashReadRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSEFlashReadRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSEFlashReadRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSEFlashWriteRequest */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSEFlashWriteRequest message;
} FRSEFlashWriteRequest;

static PyTypeObject FRSEFlashWriteRequestType;


#define FRSEFlashWriteRequest_Check(v)  ((v)->ob_type == &FRSEFlashWriteRequestType)

static struct PyMemberDef FRSEFlashWriteRequest_members[] = {
    {"length", T_SHORT, offsetof(FRSEFlashWriteRequest, message.length), 0, "length"},
    {"FRStype", T_SHORT, offsetof(FRSEFlashWriteRequest, message.FRStype), 0, "FRStype"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSEFlashWriteRequest_str(FRSEFlashWriteRequest * obj)
{
    char str[1024];
    freespace_printFRSEFlashWriteRequestStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSEFlashWriteRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSEFlashWriteRequest",      /*tp_name*/
    sizeof(FRSEFlashWriteRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSEFlashWriteRequest_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSEFlashWriteRequest_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSEFlashWriteData */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSEFlashWriteData message;
} FRSEFlashWriteData;

static PyTypeObject FRSEFlashWriteDataType;


#define FRSEFlashWriteData_Check(v)  ((v)->ob_type == &FRSEFlashWriteDataType)

static struct PyMemberDef FRSEFlashWriteData_members[] = {
    {"wordOffset", T_SHORT, offsetof(FRSEFlashWriteData, message.wordOffset), 0, "wordOffset"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSEFlashWriteData_str(FRSEFlashWriteData * obj)
{
    char str[1024];
    freespace_printFRSEFlashWriteDataStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSEFlashWriteDataType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSEFlashWriteData",      /*tp_name*/
    sizeof(FRSEFlashWriteData),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSEFlashWriteData_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSEFlashWriteData_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type LoopBootloaderCommand */
typedef struct {
    PyObject_HEAD
    
    struct freespace_LoopBootloaderCommand message;
} LoopBootloaderCommand;

static PyTypeObject LoopBootloaderCommandType;


#define LoopBootloaderCommand_Check(v)  ((v)->ob_type == &LoopBootloaderCommandType)

static struct PyMemberDef LoopBootloaderCommand_members[] = {
    {"loaderKeyCommand", T_UINT, offsetof(LoopBootloaderCommand, message.loaderKeyCommand), 0, "Loader Key Commands:	     Launch application: 0xb9e3aa6e 	     Upgrade Image:      0x461c5592 	     Validate Image:     0xc452801e"},
    {NULL}  /* Sentinel */
};

static PyObject *
LoopBootloaderCommand_str(LoopBootloaderCommand * obj)
{
    char str[1024];
    freespace_printLoopBootloaderCommandStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject LoopBootloaderCommandType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.LoopBootloaderCommand",      /*tp_name*/
    sizeof(LoopBootloaderCommand),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)LoopBootloaderCommand_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from host to a handheld(loop) to trigger a reset into the bootloader. 	The 32-bit loaderkey command value is placed at a special location in RAM and the system is reset. 	If the loaderkey has the proper value, the bootloader will act on the command. 	Otherwise the bootloader will transfer control to the application immediately.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    LoopBootloaderCommand_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type LoopBootloaderStatusRequest */
typedef struct {
    PyObject_HEAD

} LoopBootloaderStatusRequest;

static PyTypeObject LoopBootloaderStatusRequestType;


#define LoopBootloaderStatusRequest_Check(v)  ((v)->ob_type == &LoopBootloaderStatusRequestType)

static PyTypeObject LoopBootloaderStatusRequestType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.LoopBootloaderStatusRequest",      /*tp_name*/
    sizeof(LoopBootloaderStatusRequest),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from host to a handheld to request that it send a bootloader status report message.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type Gen4SDAFormat */
typedef struct {
    PyObject_HEAD
    
    struct freespace_Gen4SDAFormat message;
} Gen4SDAFormat;

static PyTypeObject Gen4SDAFormatType;


#define Gen4SDAFormat_Check(v)  ((v)->ob_type == &Gen4SDAFormatType)

static struct PyMemberDef Gen4SDAFormat_members[] = {
    {"reportCount", T_SHORT, offsetof(Gen4SDAFormat, message.reportCount), READONLY, "reportCount"},
    {"left", T_BOOL, offsetof(Gen4SDAFormat, message.left), READONLY, "left"},
    {"right", T_BOOL, offsetof(Gen4SDAFormat, message.right), READONLY, "right"},
    {"scroll", T_BOOL, offsetof(Gen4SDAFormat, message.scroll), READONLY, "scroll"},
    {"hold", T_BOOL, offsetof(Gen4SDAFormat, message.hold), READONLY, "hold"},
    {"triangle", T_BOOL, offsetof(Gen4SDAFormat, message.triangle), READONLY, "triangle"},
    {"deltaWheel", T_BYTE, offsetof(Gen4SDAFormat, message.deltaWheel), READONLY, "deltaWheel"},
    {"accelX", T_SHORT, offsetof(Gen4SDAFormat, message.accelX), READONLY, "accelX"},
    {"accelY", T_SHORT, offsetof(Gen4SDAFormat, message.accelY), READONLY, "accelY"},
    {"accelZ", T_SHORT, offsetof(Gen4SDAFormat, message.accelZ), READONLY, "accelZ"},
    {"rotationX", T_SHORT, offsetof(Gen4SDAFormat, message.rotationX), READONLY, "rotationX"},
    {"rotationY", T_SHORT, offsetof(Gen4SDAFormat, message.rotationY), READONLY, "rotationY"},
    {"rotationZ", T_SHORT, offsetof(Gen4SDAFormat, message.rotationZ), READONLY, "rotationZ"},
    {"xMov", T_BYTE, offsetof(Gen4SDAFormat, message.xMov), READONLY, "xMov"},
    {"yMov", T_BYTE, offsetof(Gen4SDAFormat, message.yMov), READONLY, "yMov"},
    {"sampleBase", T_UINT, offsetof(Gen4SDAFormat, message.sampleBase), READONLY, "sampleBase"},
    {"command", T_USHORT, offsetof(Gen4SDAFormat, message.command), READONLY, "command"},
    {NULL}  /* Sentinel */
};

static PyObject *
Gen4SDAFormat_str(Gen4SDAFormat * obj)
{
    char str[1024];
    freespace_printGen4SDAFormatStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject Gen4SDAFormatType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.Gen4SDAFormat",      /*tp_name*/
    sizeof(Gen4SDAFormat),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)Gen4SDAFormat_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "The Gen4 SDA format is used by FSRK Gen4 dongle, which has USB product ID = 0xC007.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    Gen4SDAFormat_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type CRCErrorIndication */
typedef struct {
    PyObject_HEAD

} CRCErrorIndication;

static PyTypeObject CRCErrorIndicationType;


#define CRCErrorIndication_Check(v)  ((v)->ob_type == &CRCErrorIndicationType)

static PyTypeObject CRCErrorIndicationType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.CRCErrorIndication",      /*tp_name*/
    sizeof(CRCErrorIndication),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "The factory test dongle will send this message when a CRC message occurred over the wired factory test interface.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FactoryCalibrationReadData */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FactoryCalibrationReadData message;
} FactoryCalibrationReadData;

static PyTypeObject FactoryCalibrationReadDataType;


#define FactoryCalibrationReadData_Check(v)  ((v)->ob_type == &FactoryCalibrationReadDataType)

static struct PyMemberDef FactoryCalibrationReadData_members[] = {
    {"wordOffset", T_UBYTE, offsetof(FactoryCalibrationReadData, message.wordOffset), READONLY, "wordOffset indicates the number of words offset from the beginning of the factory calibration data the message begins."},
    {"dataLength", T_UBYTE, offsetof(FactoryCalibrationReadData, message.dataLength), READONLY, "Indicates the number of data words contained within the message, typically 5 words."},
    {NULL}  /* Sentinel */
};

static PyObject *
FactoryCalibrationReadData_str(FactoryCalibrationReadData * obj)
{
    char str[1024];
    freespace_printFactoryCalibrationReadDataStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FactoryCalibrationReadDataType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FactoryCalibrationReadData",      /*tp_name*/
    sizeof(FactoryCalibrationReadData),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FactoryCalibrationReadData_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the loop to the dongle to convey the factory calibration data. This is only used by the Zebra architecture products.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FactoryCalibrationReadData_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FTDongleStatusResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FTDongleStatusResponse message;
} FTDongleStatusResponse;

static PyTypeObject FTDongleStatusResponseType;


#define FTDongleStatusResponse_Check(v)  ((v)->ob_type == &FTDongleStatusResponseType)

static struct PyMemberDef FTDongleStatusResponse_members[] = {
    {"power", T_BOOL, offsetof(FTDongleStatusResponse, message.power), READONLY, "0: DUT power is disabled, 1: DUT power is enabled"},
    {"reset", T_BOOL, offsetof(FTDongleStatusResponse, message.reset), READONLY, "0: DUT reset is deasserted, 1: DUT is reset asserted"},
    {"presence", T_BOOL, offsetof(FTDongleStatusResponse, message.presence), READONLY, "0: presence signal is deasserted, 1: presence signal is asserted"},
    {"status", T_UBYTE, offsetof(FTDongleStatusResponse, message.status), READONLY, "Status:	    -0xFF: This is not a factory calibration dongle. Not guaranteed to be supported.	    -0x00: Idle. The factory calibration dongle is waiting to be connected to a Loop.	    -0x01: Connecting. The factory calibration dongle is currently debouncing its Loop presence detect line or synchronizing with a Loop.	    -0x02: Connected. The factory calibration dongle is fully connected to a Loop. Communications have been established and command/response messages can be sent to/received from the Loop."},
    {NULL}  /* Sentinel */
};

static PyObject *
FTDongleStatusResponse_str(FTDongleStatusResponse * obj)
{
    char str[1024];
    freespace_printFTDongleStatusResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FTDongleStatusResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FTDongleStatusResponse",      /*tp_name*/
    sizeof(FTDongleStatusResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FTDongleStatusResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the FT dongle towards the host to indicate the current status of the dongle",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FTDongleStatusResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type StatisticsResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_StatisticsResponse message;
} StatisticsResponse;

static PyTypeObject StatisticsResponseType;


#define StatisticsResponse_Check(v)  ((v)->ob_type == &StatisticsResponseType)

static struct PyMemberDef StatisticsResponse_members[] = {
    {"stackSpace", T_SHORT, offsetof(StatisticsResponse, message.stackSpace), READONLY, "stackSpace"},
    {"runTime", T_SHORT, offsetof(StatisticsResponse, message.runTime), READONLY, "runTime"},
    {NULL}  /* Sentinel */
};

static PyObject *
StatisticsResponse_str(StatisticsResponse * obj)
{
    char str[1024];
    freespace_printStatisticsResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject StatisticsResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.StatisticsResponse",      /*tp_name*/
    sizeof(StatisticsResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)StatisticsResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent in response to a statistics request.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    StatisticsResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ZebraSystemTestResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ZebraSystemTestResponse message;
} ZebraSystemTestResponse;

static PyTypeObject ZebraSystemTestResponseType;


#define ZebraSystemTestResponse_Check(v)  ((v)->ob_type == &ZebraSystemTestResponseType)

static struct PyMemberDef ZebraSystemTestResponse_members[] = {
    {"reset", T_BOOL, offsetof(ZebraSystemTestResponse, message.reset), READONLY, "1 to reset, 0 for normal"},
    {"mode", T_BOOL, offsetof(ZebraSystemTestResponse, message.mode), READONLY, "0 - RF+USB, 1 - USB"},
    {"pcSequence", T_USHORT, offsetof(ZebraSystemTestResponse, message.pcSequence), READONLY, "pcSequence"},
    {"dongleOutSequence", T_USHORT, offsetof(ZebraSystemTestResponse, message.dongleOutSequence), READONLY, "dongleOutSequence"},
    {"rfSequence", T_USHORT, offsetof(ZebraSystemTestResponse, message.rfSequence), READONLY, "rfSequence"},
    {"dongleInSequence", T_USHORT, offsetof(ZebraSystemTestResponse, message.dongleInSequence), READONLY, "dongleInSequence"},
    {NULL}  /* Sentinel */
};

static PyObject *
ZebraSystemTestResponse_str(ZebraSystemTestResponse * obj)
{
    char str[1024];
    freespace_printZebraSystemTestResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ZebraSystemTestResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ZebraSystemTestResponse",      /*tp_name*/
    sizeof(ZebraSystemTestResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ZebraSystemTestResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is used during Zebra System test to collection link(RF+USB) strength statistics.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ZebraSystemTestResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ProductIDResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ProductIDResponse message;
} ProductIDResponse;

static PyTypeObject ProductIDResponseType;


#define ProductIDResponse_Check(v)  ((v)->ob_type == &ProductIDResponseType)

static struct PyMemberDef ProductIDResponse_members[] = {
    {"swPartNumber", T_UINT, offsetof(ProductIDResponse, message.swPartNumber), READONLY, "swPartNumber"},
    {"swBuildNumber", T_UINT, offsetof(ProductIDResponse, message.swBuildNumber), READONLY, "swBuildNumber"},
    {"swicn", T_UINT, offsetof(ProductIDResponse, message.swicn), READONLY, "swicn"},
    {"swVersionPatch", T_SHORT, offsetof(ProductIDResponse, message.swVersionPatch), READONLY, "swVersionPatch"},
    {"swVersionMinor", T_UBYTE, offsetof(ProductIDResponse, message.swVersionMinor), READONLY, "swVersionMinor"},
    {"swVersionMajor", T_UBYTE, offsetof(ProductIDResponse, message.swVersionMajor), READONLY, "swVersionMajor"},
    {"hwPlatformID", T_UBYTE, offsetof(ProductIDResponse, message.hwPlatformID), READONLY, "hwPlatformID"},
    {"hwRevision", T_UBYTE, offsetof(ProductIDResponse, message.hwRevision), READONLY, "hwRevision"},
    {"serialNumber", T_UINT, offsetof(ProductIDResponse, message.serialNumber), READONLY, "serialNumber"},
    {"deviceClass", T_BOOL, offsetof(ProductIDResponse, message.deviceClass), READONLY, "The device class represents the characteristics of the device providing the product ID. 	 0: device type not known.	 1: non-data-generating device. The Zebra dongle device class is 1	 2: data-generating device. The Zebra loop device class is 2."},
    {"invalidNS", T_BOOL, offsetof(ProductIDResponse, message.invalidNS), READONLY, "0: read serial number is valid, 1 read serial number is invalid; retry read until valid."},
    {NULL}  /* Sentinel */
};

static PyObject *
ProductIDResponse_str(ProductIDResponse * obj)
{
    char str[1024];
    freespace_printProductIDResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ProductIDResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ProductIDResponse",      /*tp_name*/
    sizeof(ProductIDResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ProductIDResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the polled device towards the host to convey the product ID information.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ProductIDResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type LinkStatus */
typedef struct {
    PyObject_HEAD
    
    struct freespace_LinkStatus message;
} LinkStatus;

static PyTypeObject LinkStatusType;


#define LinkStatus_Check(v)  ((v)->ob_type == &LinkStatusType)

static struct PyMemberDef LinkStatus_members[] = {
    {"status", T_UBYTE, offsetof(LinkStatus, message.status), READONLY, "status"},
    {"mode", T_UBYTE, offsetof(LinkStatus, message.mode), READONLY, "mode"},
    {"resetStatus", T_UBYTE, offsetof(LinkStatus, message.resetStatus), READONLY, "resetStatus"},
    {NULL}  /* Sentinel */
};

static PyObject *
LinkStatus_str(LinkStatus * obj)
{
    char str[1024];
    freespace_printLinkStatusStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject LinkStatusType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.LinkStatus",      /*tp_name*/
    sizeof(LinkStatus),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)LinkStatus_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from a compliance test-ready dongle to indicate the dongle's current status.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    LinkStatus_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type AlwaysOnResponse */
typedef struct {
    PyObject_HEAD

} AlwaysOnResponse;

static PyTypeObject AlwaysOnResponseType;


#define AlwaysOnResponse_Check(v)  ((v)->ob_type == &AlwaysOnResponseType)

static PyTypeObject AlwaysOnResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.AlwaysOnResponse",      /*tp_name*/
    sizeof(AlwaysOnResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from a the loop to acknowledge an always on mode request message.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type SPIOperationResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_SPIOperationResponse message;
} SPIOperationResponse;

static PyTypeObject SPIOperationResponseType;


#define SPIOperationResponse_Check(v)  ((v)->ob_type == &SPIOperationResponseType)

static struct PyMemberDef SPIOperationResponse_members[] = {
    {"byte0", T_UBYTE, offsetof(SPIOperationResponse, message.byte0), READONLY, "byte0"},
    {"byte1", T_UBYTE, offsetof(SPIOperationResponse, message.byte1), READONLY, "byte1"},
    {"byte2", T_UBYTE, offsetof(SPIOperationResponse, message.byte2), READONLY, "byte2"},
    {"byte3", T_UBYTE, offsetof(SPIOperationResponse, message.byte3), READONLY, "byte3"},
    {"byte4", T_UBYTE, offsetof(SPIOperationResponse, message.byte4), READONLY, "byte4"},
    {"byte5", T_UBYTE, offsetof(SPIOperationResponse, message.byte5), READONLY, "byte5"},
    {"byte6", T_UBYTE, offsetof(SPIOperationResponse, message.byte6), READONLY, "byte6"},
    {"byte7", T_UBYTE, offsetof(SPIOperationResponse, message.byte7), READONLY, "byte7"},
    {"byte8", T_UBYTE, offsetof(SPIOperationResponse, message.byte8), READONLY, "byte8"},
    {"byte9", T_UBYTE, offsetof(SPIOperationResponse, message.byte9), READONLY, "byte9"},
    {"byte10", T_UBYTE, offsetof(SPIOperationResponse, message.byte10), READONLY, "byte10"},
    {"byte11", T_UBYTE, offsetof(SPIOperationResponse, message.byte11), READONLY, "byte11"},
    {"byte12", T_UBYTE, offsetof(SPIOperationResponse, message.byte12), READONLY, "byte12"},
    {"byte13", T_UBYTE, offsetof(SPIOperationResponse, message.byte13), READONLY, "byte13"},
    {"byte14", T_UBYTE, offsetof(SPIOperationResponse, message.byte14), READONLY, "byte14"},
    {"byte15", T_UBYTE, offsetof(SPIOperationResponse, message.byte15), READONLY, "byte15"},
    {"byte16", T_UBYTE, offsetof(SPIOperationResponse, message.byte16), READONLY, "byte16"},
    {"byte17", T_UBYTE, offsetof(SPIOperationResponse, message.byte17), READONLY, "byte17"},
    {"byte18", T_UBYTE, offsetof(SPIOperationResponse, message.byte18), READONLY, "byte18"},
    {"byte19", T_UBYTE, offsetof(SPIOperationResponse, message.byte19), READONLY, "byte19"},
    {"byte20", T_UBYTE, offsetof(SPIOperationResponse, message.byte20), READONLY, "byte20"},
    {"byte21", T_UBYTE, offsetof(SPIOperationResponse, message.byte21), READONLY, "byte21"},
    {"byte22", T_UBYTE, offsetof(SPIOperationResponse, message.byte22), READONLY, "byte22"},
    {"byte23", T_UBYTE, offsetof(SPIOperationResponse, message.byte23), READONLY, "byte23"},
    {"length", T_UBYTE, offsetof(SPIOperationResponse, message.length), READONLY, "length"},
    {NULL}  /* Sentinel */
};

static PyObject *
SPIOperationResponse_str(SPIOperationResponse * obj)
{
    char str[1024];
    freespace_printSPIOperationResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject SPIOperationResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.SPIOperationResponse",      /*tp_name*/
    sizeof(SPIOperationResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)SPIOperationResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent in response to an SPI operation request generic out message. 	 This format is used for the 27 byte (Gen4) size generic in message.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    SPIOperationResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type EventReportConfigurationResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_EventReportConfigurationResponse message;
} EventReportConfigurationResponse;

static PyTypeObject EventReportConfigurationResponseType;


#define EventReportConfigurationResponse_Check(v)  ((v)->ob_type == &EventReportConfigurationResponseType)

static struct PyMemberDef EventReportConfigurationResponse_members[] = {
    {"intc", T_BOOL, offsetof(EventReportConfigurationResponse, message.intc), READONLY, "Summary interrupt detected."},
    {"xyMov", T_BOOL, offsetof(EventReportConfigurationResponse, message.xyMov), READONLY, "X-Y pointer movement data ready."},
    {"acSt", T_BOOL, offsetof(EventReportConfigurationResponse, message.acSt), READONLY, "Activity classification status change"},
    {"reset", T_BOOL, offsetof(EventReportConfigurationResponse, message.reset), READONLY, "Test module reset detected."},
    {"motDr", T_BOOL, offsetof(EventReportConfigurationResponse, message.motDr), READONLY, "Motion data ready"},
    {"wom", T_BOOL, offsetof(EventReportConfigurationResponse, message.wom), READONLY, "Wake-on-motion detected."},
    {"motOv", T_BOOL, offsetof(EventReportConfigurationResponse, message.motOv), READONLY, "Motion data overflow"},
    {"acEv", T_BOOL, offsetof(EventReportConfigurationResponse, message.acEv), READONLY, "Activity classification event detected."},
    {"sdaDr", T_BOOL, offsetof(EventReportConfigurationResponse, message.sdaDr), READONLY, "SDA data ready."},
    {"sdaOv", T_BOOL, offsetof(EventReportConfigurationResponse, message.sdaOv), READONLY, "SDA data overflow."},
    {"cfgSt", T_BOOL, offsetof(EventReportConfigurationResponse, message.cfgSt), READONLY, "Configuration StatusChange"},
    {NULL}  /* Sentinel */
};

static PyObject *
EventReportConfigurationResponse_str(EventReportConfigurationResponse * obj)
{
    char str[1024];
    freespace_printEventReportConfigurationResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject EventReportConfigurationResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.EventReportConfigurationResponse",      /*tp_name*/
    sizeof(EventReportConfigurationResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)EventReportConfigurationResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from the FSRK-E adapter test module to the host in response to a request for the current configuration for event reporting.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    EventReportConfigurationResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type EventReport */
typedef struct {
    PyObject_HEAD
    
    struct freespace_EventReport message;
} EventReport;

static PyTypeObject EventReportType;


#define EventReport_Check(v)  ((v)->ob_type == &EventReportType)

static struct PyMemberDef EventReport_members[] = {
    {"register0", T_USHORT, offsetof(EventReport, message.register0), READONLY, "register0"},
    {"register1", T_USHORT, offsetof(EventReport, message.register1), READONLY, "register1"},
    {"register2", T_USHORT, offsetof(EventReport, message.register2), READONLY, "register2"},
    {"register3", T_USHORT, offsetof(EventReport, message.register3), READONLY, "register3"},
    {"register4", T_USHORT, offsetof(EventReport, message.register4), READONLY, "register4"},
    {"register5", T_USHORT, offsetof(EventReport, message.register5), READONLY, "register5"},
    {"register6", T_USHORT, offsetof(EventReport, message.register6), READONLY, "register6"},
    {"register7", T_USHORT, offsetof(EventReport, message.register7), READONLY, "register7"},
    {NULL}  /* Sentinel */
};

static PyObject *
EventReport_str(EventReport * obj)
{
    char str[1024];
    freespace_printEventReportStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject EventReportType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.EventReport",      /*tp_name*/
    sizeof(EventReport),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)EventReport_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from the FSRK-E adapter test module to report that a particular 	 event, for which event reporting has been enabled, has occured. 	 The contents of the report are a set of 8 register data reports. Each 2 bytes. 	 The selection of registers reported is determined by the adapter board firmware.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    EventReport_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type UnknownCRSNotificationResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_UnknownCRSNotificationResponse message;
} UnknownCRSNotificationResponse;

static PyTypeObject UnknownCRSNotificationResponseType;


#define UnknownCRSNotificationResponse_Check(v)  ((v)->ob_type == &UnknownCRSNotificationResponseType)

static struct PyMemberDef UnknownCRSNotificationResponse_members[] = {
    {"unknownReportID", T_UBYTE, offsetof(UnknownCRSNotificationResponse, message.unknownReportID), READONLY, "This is the HID report ID of the unknown message received by the handheld."},
    {"unknownSubMessageID", T_UBYTE, offsetof(UnknownCRSNotificationResponse, message.unknownSubMessageID), READONLY, "This is the HID sub-message ID of the unknown message received by the handheld."},
    {NULL}  /* Sentinel */
};

static PyObject *
UnknownCRSNotificationResponse_str(UnknownCRSNotificationResponse * obj)
{
    char str[1024];
    freespace_printUnknownCRSNotificationResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject UnknownCRSNotificationResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.UnknownCRSNotificationResponse",      /*tp_name*/
    sizeof(UnknownCRSNotificationResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)UnknownCRSNotificationResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from a handheld to a base station. It indicates that the handheld did not recognize a CRS message that the base station had sent. 	 This message will never be sent over USB",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    UnknownCRSNotificationResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSLoopReadResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSLoopReadResponse message;
} FRSLoopReadResponse;

static PyTypeObject FRSLoopReadResponseType;


#define FRSLoopReadResponse_Check(v)  ((v)->ob_type == &FRSLoopReadResponseType)

static struct PyMemberDef FRSLoopReadResponse_members[] = {
    {"wordOffset", T_USHORT, offsetof(FRSLoopReadResponse, message.wordOffset), READONLY, "Word Offset indicates the number of words the data is offset from the beginning of the record"},
    {"status", T_UBYTE, offsetof(FRSLoopReadResponse, message.status), READONLY, "Status:	0: no error	1: unrecognized FRS type	2: busy	3: read completed	4: offset out of range	5: record empty"},
    {"dataLength", T_UBYTE, offsetof(FRSLoopReadResponse, message.dataLength), READONLY, "Data Length indicates the number of data words contained within the message, typically 5 words"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSLoopReadResponse_str(FRSLoopReadResponse * obj)
{
    char str[1024];
    freespace_printFRSLoopReadResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSLoopReadResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSLoopReadResponse",      /*tp_name*/
    sizeof(FRSLoopReadResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSLoopReadResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the loop to the dongle to convey an FSR record.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSLoopReadResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSLoopWriteResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSLoopWriteResponse message;
} FRSLoopWriteResponse;

static PyTypeObject FRSLoopWriteResponseType;


#define FRSLoopWriteResponse_Check(v)  ((v)->ob_type == &FRSLoopWriteResponseType)

static struct PyMemberDef FRSLoopWriteResponse_members[] = {
    {"wordOffset", T_USHORT, offsetof(FRSLoopWriteResponse, message.wordOffset), READONLY, "wordOffset"},
    {"status", T_UBYTE, offsetof(FRSLoopWriteResponse, message.status), READONLY, "Status/Error:	0: word received	1: unrecognized FRS type	2: busy	3: write completed	4: write mode entered already	5: write failed	6: data received while not in write mode	7: invalid length	8: record valid (the complete record passed internal validation checks)	9:record invalid (the complete record failed internal validation checks)"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSLoopWriteResponse_str(FRSLoopWriteResponse * obj)
{
    char str[1024];
    freespace_printFRSLoopWriteResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSLoopWriteResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSLoopWriteResponse",      /*tp_name*/
    sizeof(FRSLoopWriteResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSLoopWriteResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This is sent from the loop to the host to indicate status of the write operation.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSLoopWriteResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSDongleReadResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSDongleReadResponse message;
} FRSDongleReadResponse;

static PyTypeObject FRSDongleReadResponseType;


#define FRSDongleReadResponse_Check(v)  ((v)->ob_type == &FRSDongleReadResponseType)

static struct PyMemberDef FRSDongleReadResponse_members[] = {
    {"wordOffset", T_USHORT, offsetof(FRSDongleReadResponse, message.wordOffset), READONLY, "wordOffset"},
    {"status", T_UBYTE, offsetof(FRSDongleReadResponse, message.status), READONLY, "status"},
    {"dataLength", T_UBYTE, offsetof(FRSDongleReadResponse, message.dataLength), READONLY, "dataLength"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSDongleReadResponse_str(FRSDongleReadResponse * obj)
{
    char str[1024];
    freespace_printFRSDongleReadResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSDongleReadResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSDongleReadResponse",      /*tp_name*/
    sizeof(FRSDongleReadResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSDongleReadResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSDongleReadResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSDongleWriteResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSDongleWriteResponse message;
} FRSDongleWriteResponse;

static PyTypeObject FRSDongleWriteResponseType;


#define FRSDongleWriteResponse_Check(v)  ((v)->ob_type == &FRSDongleWriteResponseType)

static struct PyMemberDef FRSDongleWriteResponse_members[] = {
    {"wordOffset", T_USHORT, offsetof(FRSDongleWriteResponse, message.wordOffset), READONLY, "wordOffset"},
    {"status", T_UBYTE, offsetof(FRSDongleWriteResponse, message.status), READONLY, "status"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSDongleWriteResponse_str(FRSDongleWriteResponse * obj)
{
    char str[1024];
    freespace_printFRSDongleWriteResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSDongleWriteResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSDongleWriteResponse",      /*tp_name*/
    sizeof(FRSDongleWriteResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSDongleWriteResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSDongleWriteResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSEFlashReadResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSEFlashReadResponse message;
} FRSEFlashReadResponse;

static PyTypeObject FRSEFlashReadResponseType;


#define FRSEFlashReadResponse_Check(v)  ((v)->ob_type == &FRSEFlashReadResponseType)

static struct PyMemberDef FRSEFlashReadResponse_members[] = {
    {"wordOffset", T_USHORT, offsetof(FRSEFlashReadResponse, message.wordOffset), READONLY, "wordOffset"},
    {"status", T_UBYTE, offsetof(FRSEFlashReadResponse, message.status), READONLY, "status"},
    {"dataLength", T_UBYTE, offsetof(FRSEFlashReadResponse, message.dataLength), READONLY, "dataLength"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSEFlashReadResponse_str(FRSEFlashReadResponse * obj)
{
    char str[1024];
    freespace_printFRSEFlashReadResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSEFlashReadResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSEFlashReadResponse",      /*tp_name*/
    sizeof(FRSEFlashReadResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSEFlashReadResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSEFlashReadResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FRSEFlashWriteResponse */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FRSEFlashWriteResponse message;
} FRSEFlashWriteResponse;

static PyTypeObject FRSEFlashWriteResponseType;


#define FRSEFlashWriteResponse_Check(v)  ((v)->ob_type == &FRSEFlashWriteResponseType)

static struct PyMemberDef FRSEFlashWriteResponse_members[] = {
    {"wordOffset", T_USHORT, offsetof(FRSEFlashWriteResponse, message.wordOffset), READONLY, "wordOffset"},
    {"status", T_UBYTE, offsetof(FRSEFlashWriteResponse, message.status), READONLY, "status"},
    {NULL}  /* Sentinel */
};

static PyObject *
FRSEFlashWriteResponse_str(FRSEFlashWriteResponse * obj)
{
    char str[1024];
    freespace_printFRSEFlashWriteResponseStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FRSEFlashWriteResponseType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FRSEFlashWriteResponse",      /*tp_name*/
    sizeof(FRSEFlashWriteResponse),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FRSEFlashWriteResponse_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "Undocumented Message",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FRSEFlashWriteResponse_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type FSP2CoprocessorMessage */
typedef struct {
    PyObject_HEAD
    
    struct freespace_FSP2CoprocessorMessage message;
} FSP2CoprocessorMessage;

static PyTypeObject FSP2CoprocessorMessageType;


#define FSP2CoprocessorMessage_Check(v)  ((v)->ob_type == &FSP2CoprocessorMessageType)

static struct PyMemberDef FSP2CoprocessorMessage_members[] = {
    {"length", T_UBYTE, offsetof(FSP2CoprocessorMessage, message.length), READONLY, "Length is the length of the payload in bytes"},
    {NULL}  /* Sentinel */
};

static PyObject *
FSP2CoprocessorMessage_str(FSP2CoprocessorMessage * obj)
{
    char str[1024];
    freespace_printFSP2CoprocessorMessageStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject FSP2CoprocessorMessageType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.FSP2CoprocessorMessage",      /*tp_name*/
    sizeof(FSP2CoprocessorMessage),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)FSP2CoprocessorMessage_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This message is sent from the COP2USB adapter test module to the host. 	 It carries the entire message receieved over the coprocessor interface. 	 This message is used to test the FSP to coprocessor data flow.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    FSP2CoprocessorMessage_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type LoopBootloaderStatus */
typedef struct {
    PyObject_HEAD
    
    struct freespace_LoopBootloaderStatus message;
} LoopBootloaderStatus;

static PyTypeObject LoopBootloaderStatusType;


#define LoopBootloaderStatus_Check(v)  ((v)->ob_type == &LoopBootloaderStatusType)

static struct PyMemberDef LoopBootloaderStatus_members[] = {
    {"normalLaunch", T_BOOL, offsetof(LoopBootloaderStatus, message.normalLaunch), READONLY, "normalLaunch"},
    {"internalAppValid", T_BOOL, offsetof(LoopBootloaderStatus, message.internalAppValid), READONLY, "internalAppValid"},
    {"internalAppNotValid", T_BOOL, offsetof(LoopBootloaderStatus, message.internalAppNotValid), READONLY, "internalAppNotValid"},
    {"flashProtectionChanged", T_BOOL, offsetof(LoopBootloaderStatus, message.flashProtectionChanged), READONLY, "flashProtectionChanged"},
    {"upgradeStarted", T_BOOL, offsetof(LoopBootloaderStatus, message.upgradeStarted), READONLY, "upgradeStarted"},
    {"validateStarted", T_BOOL, offsetof(LoopBootloaderStatus, message.validateStarted), READONLY, "validateStarted"},
    {"errorOccured", T_BOOL, offsetof(LoopBootloaderStatus, message.errorOccured), READONLY, "errorOccured"},
    {"errorCode", T_UBYTE, offsetof(LoopBootloaderStatus, message.errorCode), READONLY, "Bootloader Error Codes:    0: no error    1: bad flash    2: unsupported version    3: incompatible hardware    4: invalid image    5: flash erase error    6: flash write error    7: bad encryption key    8: CRC error    9: bad write    10: overflow error"},
    {NULL}  /* Sentinel */
};

static PyObject *
LoopBootloaderStatus_str(LoopBootloaderStatus * obj)
{
    char str[1024];
    freespace_printLoopBootloaderStatusStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject LoopBootloaderStatusType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.LoopBootloaderStatus",      /*tp_name*/
    sizeof(LoopBootloaderStatus),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)LoopBootloaderStatus_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "This report conveys status and error information from the device bootloader.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    LoopBootloaderStatus_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type CRSKeepalive */
typedef struct {
    PyObject_HEAD

} CRSKeepalive;

static PyTypeObject CRSKeepaliveType;


#define CRSKeepalive_Check(v)  ((v)->ob_type == &CRSKeepaliveType)

static PyTypeObject CRSKeepaliveType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.CRSKeepalive",      /*tp_name*/
    sizeof(CRSKeepalive),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    0,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "The CRS Keepalive report is used to ensure that there is always traffic on the 	 handheld/base station CRS link. This report is never sent over the USB interface.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    0,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ButtonState */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ButtonState message;
} ButtonState;

static PyTypeObject ButtonStateType;


#define ButtonState_Check(v)  ((v)->ob_type == &ButtonStateType)

static struct PyMemberDef ButtonState_members[] = {
    {"leftButton", T_BOOL, offsetof(ButtonState, message.leftButton), READONLY, "leftButton"},
    {"rightButton", T_BOOL, offsetof(ButtonState, message.rightButton), READONLY, "rightButton"},
    {"scrollButton", T_BOOL, offsetof(ButtonState, message.scrollButton), READONLY, "scrollButton"},
    {"park", T_BOOL, offsetof(ButtonState, message.park), READONLY, "park"},
    {NULL}  /* Sentinel */
};

static PyObject *
ButtonState_str(ButtonState * obj)
{
    char str[1024];
    freespace_printButtonStateStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ButtonStateType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ButtonState",      /*tp_name*/
    sizeof(ButtonState),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ButtonState_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "The button state report is sent from the handheld to the base station over the CRS link to indicate a change in the state of the buttons on the handheld.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ButtonState_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};



/* ----------------------------------------------------- */
/* Declarations for objects of type ScrollMotion */
typedef struct {
    PyObject_HEAD
    
    struct freespace_ScrollMotion message;
} ScrollMotion;

static PyTypeObject ScrollMotionType;


#define ScrollMotion_Check(v)  ((v)->ob_type == &ScrollMotionType)

static struct PyMemberDef ScrollMotion_members[] = {
    {"deltaWheel", T_BYTE, offsetof(ScrollMotion, message.deltaWheel), READONLY, "deltaWheel"},
    {NULL}  /* Sentinel */
};

static PyObject *
ScrollMotion_str(ScrollMotion * obj)
{
    char str[1024];
    freespace_printScrollMotionStr(str, sizeof(str), &(obj->message));
    if (str != NULL) {
        return PyString_FromString(str);
    }
    
    return NULL;
}

static PyTypeObject ScrollMotionType = {
    PyObject_HEAD_INIT(NULL)
    0,                         /*ob_size*/
    "freespace.ScrollMotion",      /*tp_name*/
    sizeof(ScrollMotion),          /*tp_basicsize*/
    0,                         /*tp_itemsize*/
    0,                         /*tp_dealloc*/
    0,                         /*tp_print*/
    0,                         /*tp_getattr*/
    0,                         /*tp_setattr*/
    0,                         /*tp_compare*/
    0,                         /*tp_repr*/
    0,                         /*tp_as_number*/
    0,                         /*tp_as_sequence*/
    0,                         /*tp_as_mapping*/
    0,                         /*tp_hash */
    0,                         /*tp_call*/
    (reprfunc)ScrollMotion_str,   /*tp_str*/
    0,                         /*tp_getattro*/
    0,                         /*tp_setattro*/
    0,                         /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
    "The button state report is sent from the handheld to the base station over the CRS link to indicate a change in the state of the buttons on the handheld.",    /* tp_doc */
    0,                              /* tp_traverse */
    0,                              /* tp_clear */
    0,                              /* tp_richcompare */
    0,                              /* tp_weaklistoffset */
    0,                              /* tp_iter */
    0,                              /* tp_iternext */
    0,                              /* tp_methods */
    ScrollMotion_members,       /* tp_members */
    0,                              /* tp_getset */
    0,                              /* tp_base */
    0,                              /* tp_dict */
    0,                              /* tp_descr_get */
    0,                              /* tp_descr_set */
    0,                              /* tp_dictoffset */
    0,                              /* tp_init */
    0,                              /* tp_alloc */
};


/* ----------------------------------------------------- */
int encodeMessage(PyObject* messageObject, uint8_t* message, int maxlen) {
    if (CoprocessorOutReport_Check(messageObject)) {
        return freespace_encodeCoprocessorOutReport(&(((CoprocessorOutReport*) messageObject)->message), message, maxlen);
    }
    if (BatteryLevelRequest_Check(messageObject)) {
        return freespace_encodeBatteryLevelRequest(message, maxlen);
    }
    if (DataMotionControl_Check(messageObject)) {
        return freespace_encodeDataMotionControl(&(((DataMotionControl*) messageObject)->message), message, maxlen);
    }
    if (ConfigurationMessage_Check(messageObject)) {
        return freespace_encodeConfigurationMessage(&(((ConfigurationMessage*) messageObject)->message), message, maxlen);
    }
    if (PairingMessage_Check(messageObject)) {
        return freespace_encodePairingMessage(message, maxlen);
    }
    if (DebugMessage_Check(messageObject)) {
        return freespace_encodeDebugMessage(message, maxlen);
    }
    if (FactoryCalibrationReadRequest_Check(messageObject)) {
        return freespace_encodeFactoryCalibrationReadRequest(&(((FactoryCalibrationReadRequest*) messageObject)->message), message, maxlen);
    }
    if (DongleReset_Check(messageObject)) {
        return freespace_encodeDongleReset(&(((DongleReset*) messageObject)->message), message, maxlen);
    }
    if (FTDongleStatusRequest_Check(messageObject)) {
        return freespace_encodeFTDongleStatusRequest(&(((FTDongleStatusRequest*) messageObject)->message), message, maxlen);
    }
    if (StatisticsRequest_Check(messageObject)) {
        return freespace_encodeStatisticsRequest(message, maxlen);
    }
    if (ZebraSystemTest_Check(messageObject)) {
        return freespace_encodeZebraSystemTest(&(((ZebraSystemTest*) messageObject)->message), message, maxlen);
    }
    if (ProductIDRequest_Check(messageObject)) {
        return freespace_encodeProductIDRequest(message, maxlen);
    }
    if (LoopLEDSetRequest_Check(messageObject)) {
        return freespace_encodeLoopLEDSetRequest(&(((LoopLEDSetRequest*) messageObject)->message), message, maxlen);
    }
    if (AlwaysOnRequest_Check(messageObject)) {
        return freespace_encodeAlwaysOnRequest(message, maxlen);
    }
    if (FrequencyFixRequest_Check(messageObject)) {
        return freespace_encodeFrequencyFixRequest(&(((FrequencyFixRequest*) messageObject)->message), message, maxlen);
    }
    if (SoftwareResetMessage_Check(messageObject)) {
        return freespace_encodeSoftwareResetMessage(&(((SoftwareResetMessage*) messageObject)->message), message, maxlen);
    }
    if (DongleRFDisableMessage_Check(messageObject)) {
        return freespace_encodeDongleRFDisableMessage(message, maxlen);
    }
    if (DongleRFSupressHomeFrequencyMessage_Check(messageObject)) {
        return freespace_encodeDongleRFSupressHomeFrequencyMessage(&(((DongleRFSupressHomeFrequencyMessage*) messageObject)->message), message, maxlen);
    }
    if (SPIOperationMessage_Check(messageObject)) {
        return freespace_encodeSPIOperationMessage(&(((SPIOperationMessage*) messageObject)->message), message, maxlen);
    }
    if (EventReportConfigSetRequest_Check(messageObject)) {
        return freespace_encodeEventReportConfigSetRequest(&(((EventReportConfigSetRequest*) messageObject)->message), message, maxlen);
    }
    if (EventReportConfigGetRequest_Check(messageObject)) {
        return freespace_encodeEventReportConfigGetRequest(message, maxlen);
    }
    if (UnknownCRSNotification_Check(messageObject)) {
        return freespace_encodeUnknownCRSNotification(&(((UnknownCRSNotification*) messageObject)->message), message, maxlen);
    }
    if (FRSLoopReadRequest_Check(messageObject)) {
        return freespace_encodeFRSLoopReadRequest(&(((FRSLoopReadRequest*) messageObject)->message), message, maxlen);
    }
    if (FRSLoopWriteRequest_Check(messageObject)) {
        return freespace_encodeFRSLoopWriteRequest(&(((FRSLoopWriteRequest*) messageObject)->message), message, maxlen);
    }
    if (FRSLoopWriteData_Check(messageObject)) {
        return freespace_encodeFRSLoopWriteData(&(((FRSLoopWriteData*) messageObject)->message), message, maxlen);
    }
    if (FRSDongleReadRequest_Check(messageObject)) {
        return freespace_encodeFRSDongleReadRequest(&(((FRSDongleReadRequest*) messageObject)->message), message, maxlen);
    }
    if (FRSDongleWriteRequest_Check(messageObject)) {
        return freespace_encodeFRSDongleWriteRequest(&(((FRSDongleWriteRequest*) messageObject)->message), message, maxlen);
    }
    if (FRSDongleWriteData_Check(messageObject)) {
        return freespace_encodeFRSDongleWriteData(&(((FRSDongleWriteData*) messageObject)->message), message, maxlen);
    }
    if (FRSEFlashReadRequest_Check(messageObject)) {
        return freespace_encodeFRSEFlashReadRequest(&(((FRSEFlashReadRequest*) messageObject)->message), message, maxlen);
    }
    if (FRSEFlashWriteRequest_Check(messageObject)) {
        return freespace_encodeFRSEFlashWriteRequest(&(((FRSEFlashWriteRequest*) messageObject)->message), message, maxlen);
    }
    if (FRSEFlashWriteData_Check(messageObject)) {
        return freespace_encodeFRSEFlashWriteData(&(((FRSEFlashWriteData*) messageObject)->message), message, maxlen);
    }
    if (LoopBootloaderCommand_Check(messageObject)) {
        return freespace_encodeLoopBootloaderCommand(&(((LoopBootloaderCommand*) messageObject)->message), message, maxlen);
    }
    if (LoopBootloaderStatusRequest_Check(messageObject)) {
        return freespace_encodeLoopBootloaderStatusRequest(message, maxlen);
    }
    return -1;
}

PyObject* decodeMessage(const uint8_t* message, int length) {
    struct freespace_message s;
    MouseMovement* mouseMovement;
    ConsumerControl* consumerControl;
    KeyboardReport* keyboardReport;
    CoprocessorInReport* coprocessorInReport;
    BatteryLevel* batteryLevel;
    BodyFrame* bodyFrame;
    UserFrame* userFrame;
    Gen4SDAFormat* gen4SDAFormat;
    FactoryCalibrationReadData* factoryCalibrationReadData;
    FTDongleStatusResponse* fTDongleStatusResponse;
    StatisticsResponse* statisticsResponse;
    ZebraSystemTestResponse* zebraSystemTestResponse;
    ProductIDResponse* productIDResponse;
    LinkStatus* linkStatus;
    SPIOperationResponse* sPIOperationResponse;
    EventReportConfigurationResponse* eventReportConfigurationResponse;
    EventReport* eventReport;
    UnknownCRSNotificationResponse* unknownCRSNotificationResponse;
    FRSLoopReadResponse* fRSLoopReadResponse;
    FRSLoopWriteResponse* fRSLoopWriteResponse;
    FRSDongleReadResponse* fRSDongleReadResponse;
    FRSDongleWriteResponse* fRSDongleWriteResponse;
    FRSEFlashReadResponse* fRSEFlashReadResponse;
    FRSEFlashWriteResponse* fRSEFlashWriteResponse;
    FSP2CoprocessorMessage* fSP2CoprocessorMessage;
    LoopBootloaderStatus* loopBootloaderStatus;
    ButtonState* buttonState;
    ScrollMotion* scrollMotion;
    
    freespace_decode_message(message, length,  &s);
    
    switch(s.messageType) {
    case FREESPACE_MESSAGE_MOUSEMOVEMENT:
        mouseMovement = (MouseMovement*)MouseMovementType.tp_alloc(&MouseMovementType, 0);
        if (mouseMovement != NULL) {
            mouseMovement->message = s.mouseMovement;
        }
        return (PyObject*)mouseMovement;
    case FREESPACE_MESSAGE_CONSUMERCONTROL:
        consumerControl = (ConsumerControl*)ConsumerControlType.tp_alloc(&ConsumerControlType, 0);
        if (consumerControl != NULL) {
            consumerControl->message = s.consumerControl;
        }
        return (PyObject*)consumerControl;
    case FREESPACE_MESSAGE_KEYBOARDREPORT:
        keyboardReport = (KeyboardReport*)KeyboardReportType.tp_alloc(&KeyboardReportType, 0);
        if (keyboardReport != NULL) {
            keyboardReport->message = s.keyboardReport;
        }
        return (PyObject*)keyboardReport;
    case FREESPACE_MESSAGE_COPROCESSORINREPORT:
        coprocessorInReport = (CoprocessorInReport*)CoprocessorInReportType.tp_alloc(&CoprocessorInReportType, 0);
        if (coprocessorInReport != NULL) {
            coprocessorInReport->message = s.coprocessorInReport;
        }
        return (PyObject*)coprocessorInReport;
    case FREESPACE_MESSAGE_BATTERYLEVEL:
        batteryLevel = (BatteryLevel*)BatteryLevelType.tp_alloc(&BatteryLevelType, 0);
        if (batteryLevel != NULL) {
            batteryLevel->message = s.batteryLevel;
        }
        return (PyObject*)batteryLevel;
    case FREESPACE_MESSAGE_BODYFRAME:
        bodyFrame = (BodyFrame*)BodyFrameType.tp_alloc(&BodyFrameType, 0);
        if (bodyFrame != NULL) {
            bodyFrame->message = s.bodyFrame;
        }
        return (PyObject*)bodyFrame;
    case FREESPACE_MESSAGE_USERFRAME:
        userFrame = (UserFrame*)UserFrameType.tp_alloc(&UserFrameType, 0);
        if (userFrame != NULL) {
            userFrame->message = s.userFrame;
        }
        return (PyObject*)userFrame;
    case FREESPACE_MESSAGE_GEN4SDAFORMAT:
        gen4SDAFormat = (Gen4SDAFormat*)Gen4SDAFormatType.tp_alloc(&Gen4SDAFormatType, 0);
        if (gen4SDAFormat != NULL) {
            gen4SDAFormat->message = s.gen4SDAFormat;
        }
        return (PyObject*)gen4SDAFormat;
    case FREESPACE_MESSAGE_FACTORYCALIBRATIONREADDATA:
        factoryCalibrationReadData = (FactoryCalibrationReadData*)FactoryCalibrationReadDataType.tp_alloc(&FactoryCalibrationReadDataType, 0);
        if (factoryCalibrationReadData != NULL) {
            factoryCalibrationReadData->message = s.factoryCalibrationReadData;
        }
        return (PyObject*)factoryCalibrationReadData;
    case FREESPACE_MESSAGE_FTDONGLESTATUSRESPONSE:
        fTDongleStatusResponse = (FTDongleStatusResponse*)FTDongleStatusResponseType.tp_alloc(&FTDongleStatusResponseType, 0);
        if (fTDongleStatusResponse != NULL) {
            fTDongleStatusResponse->message = s.fTDongleStatusResponse;
        }
        return (PyObject*)fTDongleStatusResponse;
    case FREESPACE_MESSAGE_STATISTICSRESPONSE:
        statisticsResponse = (StatisticsResponse*)StatisticsResponseType.tp_alloc(&StatisticsResponseType, 0);
        if (statisticsResponse != NULL) {
            statisticsResponse->message = s.statisticsResponse;
        }
        return (PyObject*)statisticsResponse;
    case FREESPACE_MESSAGE_ZEBRASYSTEMTESTRESPONSE:
        zebraSystemTestResponse = (ZebraSystemTestResponse*)ZebraSystemTestResponseType.tp_alloc(&ZebraSystemTestResponseType, 0);
        if (zebraSystemTestResponse != NULL) {
            zebraSystemTestResponse->message = s.zebraSystemTestResponse;
        }
        return (PyObject*)zebraSystemTestResponse;
    case FREESPACE_MESSAGE_PRODUCTIDRESPONSE:
        productIDResponse = (ProductIDResponse*)ProductIDResponseType.tp_alloc(&ProductIDResponseType, 0);
        if (productIDResponse != NULL) {
            productIDResponse->message = s.productIDResponse;
        }
        return (PyObject*)productIDResponse;
    case FREESPACE_MESSAGE_LINKSTATUS:
        linkStatus = (LinkStatus*)LinkStatusType.tp_alloc(&LinkStatusType, 0);
        if (linkStatus != NULL) {
            linkStatus->message = s.linkStatus;
        }
        return (PyObject*)linkStatus;
    case FREESPACE_MESSAGE_SPIOPERATIONRESPONSE:
        sPIOperationResponse = (SPIOperationResponse*)SPIOperationResponseType.tp_alloc(&SPIOperationResponseType, 0);
        if (sPIOperationResponse != NULL) {
            sPIOperationResponse->message = s.sPIOperationResponse;
        }
        return (PyObject*)sPIOperationResponse;
    case FREESPACE_MESSAGE_EVENTREPORTCONFIGURATIONRESPONSE:
        eventReportConfigurationResponse = (EventReportConfigurationResponse*)EventReportConfigurationResponseType.tp_alloc(&EventReportConfigurationResponseType, 0);
        if (eventReportConfigurationResponse != NULL) {
            eventReportConfigurationResponse->message = s.eventReportConfigurationResponse;
        }
        return (PyObject*)eventReportConfigurationResponse;
    case FREESPACE_MESSAGE_EVENTREPORT:
        eventReport = (EventReport*)EventReportType.tp_alloc(&EventReportType, 0);
        if (eventReport != NULL) {
            eventReport->message = s.eventReport;
        }
        return (PyObject*)eventReport;
    case FREESPACE_MESSAGE_UNKNOWNCRSNOTIFICATIONRESPONSE:
        unknownCRSNotificationResponse = (UnknownCRSNotificationResponse*)UnknownCRSNotificationResponseType.tp_alloc(&UnknownCRSNotificationResponseType, 0);
        if (unknownCRSNotificationResponse != NULL) {
            unknownCRSNotificationResponse->message = s.unknownCRSNotificationResponse;
        }
        return (PyObject*)unknownCRSNotificationResponse;
    case FREESPACE_MESSAGE_FRSLOOPREADRESPONSE:
        fRSLoopReadResponse = (FRSLoopReadResponse*)FRSLoopReadResponseType.tp_alloc(&FRSLoopReadResponseType, 0);
        if (fRSLoopReadResponse != NULL) {
            fRSLoopReadResponse->message = s.fRSLoopReadResponse;
        }
        return (PyObject*)fRSLoopReadResponse;
    case FREESPACE_MESSAGE_FRSLOOPWRITERESPONSE:
        fRSLoopWriteResponse = (FRSLoopWriteResponse*)FRSLoopWriteResponseType.tp_alloc(&FRSLoopWriteResponseType, 0);
        if (fRSLoopWriteResponse != NULL) {
            fRSLoopWriteResponse->message = s.fRSLoopWriteResponse;
        }
        return (PyObject*)fRSLoopWriteResponse;
    case FREESPACE_MESSAGE_FRSDONGLEREADRESPONSE:
        fRSDongleReadResponse = (FRSDongleReadResponse*)FRSDongleReadResponseType.tp_alloc(&FRSDongleReadResponseType, 0);
        if (fRSDongleReadResponse != NULL) {
            fRSDongleReadResponse->message = s.fRSDongleReadResponse;
        }
        return (PyObject*)fRSDongleReadResponse;
    case FREESPACE_MESSAGE_FRSDONGLEWRITERESPONSE:
        fRSDongleWriteResponse = (FRSDongleWriteResponse*)FRSDongleWriteResponseType.tp_alloc(&FRSDongleWriteResponseType, 0);
        if (fRSDongleWriteResponse != NULL) {
            fRSDongleWriteResponse->message = s.fRSDongleWriteResponse;
        }
        return (PyObject*)fRSDongleWriteResponse;
    case FREESPACE_MESSAGE_FRSEFLASHREADRESPONSE:
        fRSEFlashReadResponse = (FRSEFlashReadResponse*)FRSEFlashReadResponseType.tp_alloc(&FRSEFlashReadResponseType, 0);
        if (fRSEFlashReadResponse != NULL) {
            fRSEFlashReadResponse->message = s.fRSEFlashReadResponse;
        }
        return (PyObject*)fRSEFlashReadResponse;
    case FREESPACE_MESSAGE_FRSEFLASHWRITERESPONSE:
        fRSEFlashWriteResponse = (FRSEFlashWriteResponse*)FRSEFlashWriteResponseType.tp_alloc(&FRSEFlashWriteResponseType, 0);
        if (fRSEFlashWriteResponse != NULL) {
            fRSEFlashWriteResponse->message = s.fRSEFlashWriteResponse;
        }
        return (PyObject*)fRSEFlashWriteResponse;
    case FREESPACE_MESSAGE_FSP2COPROCESSORMESSAGE:
        fSP2CoprocessorMessage = (FSP2CoprocessorMessage*)FSP2CoprocessorMessageType.tp_alloc(&FSP2CoprocessorMessageType, 0);
        if (fSP2CoprocessorMessage != NULL) {
            fSP2CoprocessorMessage->message = s.fSP2CoprocessorMessage;
        }
        return (PyObject*)fSP2CoprocessorMessage;
    case FREESPACE_MESSAGE_LOOPBOOTLOADERSTATUS:
        loopBootloaderStatus = (LoopBootloaderStatus*)LoopBootloaderStatusType.tp_alloc(&LoopBootloaderStatusType, 0);
        if (loopBootloaderStatus != NULL) {
            loopBootloaderStatus->message = s.loopBootloaderStatus;
        }
        return (PyObject*)loopBootloaderStatus;
    case FREESPACE_MESSAGE_BUTTONSTATE:
        buttonState = (ButtonState*)ButtonStateType.tp_alloc(&ButtonStateType, 0);
        if (buttonState != NULL) {
            buttonState->message = s.buttonState;
        }
        return (PyObject*)buttonState;
    case FREESPACE_MESSAGE_SCROLLMOTION:
        scrollMotion = (ScrollMotion*)ScrollMotionType.tp_alloc(&ScrollMotionType, 0);
        if (scrollMotion != NULL) {
            scrollMotion->message = s.scrollMotion;
        }
        return (PyObject*)scrollMotion;
    default:
        break;
    }
    
    Py_INCREF(Py_None);
    return Py_None;
}

void
addMessageObjects(PyObject* m) 
{
    // Add MouseMovement type to freespace module
    MouseMovementType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&MouseMovementType) < 0)
        return;
    Py_INCREF(&MouseMovementType);
    PyModule_AddObject(m, "MouseMovement", (PyObject *)&MouseMovementType);

    // Add ConsumerControl type to freespace module
    ConsumerControlType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ConsumerControlType) < 0)
        return;
    Py_INCREF(&ConsumerControlType);
    PyModule_AddObject(m, "ConsumerControl", (PyObject *)&ConsumerControlType);

    // Add KeyboardReport type to freespace module
    KeyboardReportType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&KeyboardReportType) < 0)
        return;
    Py_INCREF(&KeyboardReportType);
    PyModule_AddObject(m, "KeyboardReport", (PyObject *)&KeyboardReportType);

    // Add CoprocessorOutReport type to freespace module
    CoprocessorOutReportType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&CoprocessorOutReportType) < 0)
        return;
    Py_INCREF(&CoprocessorOutReportType);
    PyModule_AddObject(m, "CoprocessorOutReport", (PyObject *)&CoprocessorOutReportType);

    // Add CoprocessorInReport type to freespace module
    CoprocessorInReportType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&CoprocessorInReportType) < 0)
        return;
    Py_INCREF(&CoprocessorInReportType);
    PyModule_AddObject(m, "CoprocessorInReport", (PyObject *)&CoprocessorInReportType);

    // Add BatteryLevelRequest type to freespace module
    BatteryLevelRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&BatteryLevelRequestType) < 0)
        return;
    Py_INCREF(&BatteryLevelRequestType);
    PyModule_AddObject(m, "BatteryLevelRequest", (PyObject *)&BatteryLevelRequestType);

    // Add BatteryLevel type to freespace module
    BatteryLevelType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&BatteryLevelType) < 0)
        return;
    Py_INCREF(&BatteryLevelType);
    PyModule_AddObject(m, "BatteryLevel", (PyObject *)&BatteryLevelType);

    // Add BodyFrame type to freespace module
    BodyFrameType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&BodyFrameType) < 0)
        return;
    Py_INCREF(&BodyFrameType);
    PyModule_AddObject(m, "BodyFrame", (PyObject *)&BodyFrameType);

    // Add UserFrame type to freespace module
    UserFrameType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&UserFrameType) < 0)
        return;
    Py_INCREF(&UserFrameType);
    PyModule_AddObject(m, "UserFrame", (PyObject *)&UserFrameType);

    // Add DataMotionControl type to freespace module
    DataMotionControlType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&DataMotionControlType) < 0)
        return;
    Py_INCREF(&DataMotionControlType);
    PyModule_AddObject(m, "DataMotionControl", (PyObject *)&DataMotionControlType);

    // Add ConfigurationMessage type to freespace module
    ConfigurationMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ConfigurationMessageType) < 0)
        return;
    Py_INCREF(&ConfigurationMessageType);
    PyModule_AddObject(m, "ConfigurationMessage", (PyObject *)&ConfigurationMessageType);

    // Add PairingMessage type to freespace module
    PairingMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&PairingMessageType) < 0)
        return;
    Py_INCREF(&PairingMessageType);
    PyModule_AddObject(m, "PairingMessage", (PyObject *)&PairingMessageType);

    // Add DebugMessage type to freespace module
    DebugMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&DebugMessageType) < 0)
        return;
    Py_INCREF(&DebugMessageType);
    PyModule_AddObject(m, "DebugMessage", (PyObject *)&DebugMessageType);

    // Add FactoryCalibrationReadRequest type to freespace module
    FactoryCalibrationReadRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FactoryCalibrationReadRequestType) < 0)
        return;
    Py_INCREF(&FactoryCalibrationReadRequestType);
    PyModule_AddObject(m, "FactoryCalibrationReadRequest", (PyObject *)&FactoryCalibrationReadRequestType);

    // Add DongleReset type to freespace module
    DongleResetType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&DongleResetType) < 0)
        return;
    Py_INCREF(&DongleResetType);
    PyModule_AddObject(m, "DongleReset", (PyObject *)&DongleResetType);

    // Add FTDongleStatusRequest type to freespace module
    FTDongleStatusRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FTDongleStatusRequestType) < 0)
        return;
    Py_INCREF(&FTDongleStatusRequestType);
    PyModule_AddObject(m, "FTDongleStatusRequest", (PyObject *)&FTDongleStatusRequestType);

    // Add StatisticsRequest type to freespace module
    StatisticsRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&StatisticsRequestType) < 0)
        return;
    Py_INCREF(&StatisticsRequestType);
    PyModule_AddObject(m, "StatisticsRequest", (PyObject *)&StatisticsRequestType);

    // Add ZebraSystemTest type to freespace module
    ZebraSystemTestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ZebraSystemTestType) < 0)
        return;
    Py_INCREF(&ZebraSystemTestType);
    PyModule_AddObject(m, "ZebraSystemTest", (PyObject *)&ZebraSystemTestType);

    // Add ProductIDRequest type to freespace module
    ProductIDRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ProductIDRequestType) < 0)
        return;
    Py_INCREF(&ProductIDRequestType);
    PyModule_AddObject(m, "ProductIDRequest", (PyObject *)&ProductIDRequestType);

    // Add LoopLEDSetRequest type to freespace module
    LoopLEDSetRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&LoopLEDSetRequestType) < 0)
        return;
    Py_INCREF(&LoopLEDSetRequestType);
    PyModule_AddObject(m, "LoopLEDSetRequest", (PyObject *)&LoopLEDSetRequestType);

    // Add AlwaysOnRequest type to freespace module
    AlwaysOnRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&AlwaysOnRequestType) < 0)
        return;
    Py_INCREF(&AlwaysOnRequestType);
    PyModule_AddObject(m, "AlwaysOnRequest", (PyObject *)&AlwaysOnRequestType);

    // Add FrequencyFixRequest type to freespace module
    FrequencyFixRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FrequencyFixRequestType) < 0)
        return;
    Py_INCREF(&FrequencyFixRequestType);
    PyModule_AddObject(m, "FrequencyFixRequest", (PyObject *)&FrequencyFixRequestType);

    // Add SoftwareResetMessage type to freespace module
    SoftwareResetMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&SoftwareResetMessageType) < 0)
        return;
    Py_INCREF(&SoftwareResetMessageType);
    PyModule_AddObject(m, "SoftwareResetMessage", (PyObject *)&SoftwareResetMessageType);

    // Add DongleRFDisableMessage type to freespace module
    DongleRFDisableMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&DongleRFDisableMessageType) < 0)
        return;
    Py_INCREF(&DongleRFDisableMessageType);
    PyModule_AddObject(m, "DongleRFDisableMessage", (PyObject *)&DongleRFDisableMessageType);

    // Add DongleRFSupressHomeFrequencyMessage type to freespace module
    DongleRFSupressHomeFrequencyMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&DongleRFSupressHomeFrequencyMessageType) < 0)
        return;
    Py_INCREF(&DongleRFSupressHomeFrequencyMessageType);
    PyModule_AddObject(m, "DongleRFSupressHomeFrequencyMessage", (PyObject *)&DongleRFSupressHomeFrequencyMessageType);

    // Add SPIOperationMessage type to freespace module
    SPIOperationMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&SPIOperationMessageType) < 0)
        return;
    Py_INCREF(&SPIOperationMessageType);
    PyModule_AddObject(m, "SPIOperationMessage", (PyObject *)&SPIOperationMessageType);

    // Add EventReportConfigSetRequest type to freespace module
    EventReportConfigSetRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&EventReportConfigSetRequestType) < 0)
        return;
    Py_INCREF(&EventReportConfigSetRequestType);
    PyModule_AddObject(m, "EventReportConfigSetRequest", (PyObject *)&EventReportConfigSetRequestType);

    // Add EventReportConfigGetRequest type to freespace module
    EventReportConfigGetRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&EventReportConfigGetRequestType) < 0)
        return;
    Py_INCREF(&EventReportConfigGetRequestType);
    PyModule_AddObject(m, "EventReportConfigGetRequest", (PyObject *)&EventReportConfigGetRequestType);

    // Add UnknownCRSNotification type to freespace module
    UnknownCRSNotificationType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&UnknownCRSNotificationType) < 0)
        return;
    Py_INCREF(&UnknownCRSNotificationType);
    PyModule_AddObject(m, "UnknownCRSNotification", (PyObject *)&UnknownCRSNotificationType);

    // Add FRSLoopReadRequest type to freespace module
    FRSLoopReadRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSLoopReadRequestType) < 0)
        return;
    Py_INCREF(&FRSLoopReadRequestType);
    PyModule_AddObject(m, "FRSLoopReadRequest", (PyObject *)&FRSLoopReadRequestType);

    // Add FRSLoopWriteRequest type to freespace module
    FRSLoopWriteRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSLoopWriteRequestType) < 0)
        return;
    Py_INCREF(&FRSLoopWriteRequestType);
    PyModule_AddObject(m, "FRSLoopWriteRequest", (PyObject *)&FRSLoopWriteRequestType);

    // Add FRSLoopWriteData type to freespace module
    FRSLoopWriteDataType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSLoopWriteDataType) < 0)
        return;
    Py_INCREF(&FRSLoopWriteDataType);
    PyModule_AddObject(m, "FRSLoopWriteData", (PyObject *)&FRSLoopWriteDataType);

    // Add FRSDongleReadRequest type to freespace module
    FRSDongleReadRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSDongleReadRequestType) < 0)
        return;
    Py_INCREF(&FRSDongleReadRequestType);
    PyModule_AddObject(m, "FRSDongleReadRequest", (PyObject *)&FRSDongleReadRequestType);

    // Add FRSDongleWriteRequest type to freespace module
    FRSDongleWriteRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSDongleWriteRequestType) < 0)
        return;
    Py_INCREF(&FRSDongleWriteRequestType);
    PyModule_AddObject(m, "FRSDongleWriteRequest", (PyObject *)&FRSDongleWriteRequestType);

    // Add FRSDongleWriteData type to freespace module
    FRSDongleWriteDataType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSDongleWriteDataType) < 0)
        return;
    Py_INCREF(&FRSDongleWriteDataType);
    PyModule_AddObject(m, "FRSDongleWriteData", (PyObject *)&FRSDongleWriteDataType);

    // Add FRSEFlashReadRequest type to freespace module
    FRSEFlashReadRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSEFlashReadRequestType) < 0)
        return;
    Py_INCREF(&FRSEFlashReadRequestType);
    PyModule_AddObject(m, "FRSEFlashReadRequest", (PyObject *)&FRSEFlashReadRequestType);

    // Add FRSEFlashWriteRequest type to freespace module
    FRSEFlashWriteRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSEFlashWriteRequestType) < 0)
        return;
    Py_INCREF(&FRSEFlashWriteRequestType);
    PyModule_AddObject(m, "FRSEFlashWriteRequest", (PyObject *)&FRSEFlashWriteRequestType);

    // Add FRSEFlashWriteData type to freespace module
    FRSEFlashWriteDataType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSEFlashWriteDataType) < 0)
        return;
    Py_INCREF(&FRSEFlashWriteDataType);
    PyModule_AddObject(m, "FRSEFlashWriteData", (PyObject *)&FRSEFlashWriteDataType);

    // Add LoopBootloaderCommand type to freespace module
    LoopBootloaderCommandType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&LoopBootloaderCommandType) < 0)
        return;
    Py_INCREF(&LoopBootloaderCommandType);
    PyModule_AddObject(m, "LoopBootloaderCommand", (PyObject *)&LoopBootloaderCommandType);

    // Add LoopBootloaderStatusRequest type to freespace module
    LoopBootloaderStatusRequestType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&LoopBootloaderStatusRequestType) < 0)
        return;
    Py_INCREF(&LoopBootloaderStatusRequestType);
    PyModule_AddObject(m, "LoopBootloaderStatusRequest", (PyObject *)&LoopBootloaderStatusRequestType);

    // Add Gen4SDAFormat type to freespace module
    Gen4SDAFormatType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&Gen4SDAFormatType) < 0)
        return;
    Py_INCREF(&Gen4SDAFormatType);
    PyModule_AddObject(m, "Gen4SDAFormat", (PyObject *)&Gen4SDAFormatType);

    // Add CRCErrorIndication type to freespace module
    CRCErrorIndicationType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&CRCErrorIndicationType) < 0)
        return;
    Py_INCREF(&CRCErrorIndicationType);
    PyModule_AddObject(m, "CRCErrorIndication", (PyObject *)&CRCErrorIndicationType);

    // Add FactoryCalibrationReadData type to freespace module
    FactoryCalibrationReadDataType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FactoryCalibrationReadDataType) < 0)
        return;
    Py_INCREF(&FactoryCalibrationReadDataType);
    PyModule_AddObject(m, "FactoryCalibrationReadData", (PyObject *)&FactoryCalibrationReadDataType);

    // Add FTDongleStatusResponse type to freespace module
    FTDongleStatusResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FTDongleStatusResponseType) < 0)
        return;
    Py_INCREF(&FTDongleStatusResponseType);
    PyModule_AddObject(m, "FTDongleStatusResponse", (PyObject *)&FTDongleStatusResponseType);

    // Add StatisticsResponse type to freespace module
    StatisticsResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&StatisticsResponseType) < 0)
        return;
    Py_INCREF(&StatisticsResponseType);
    PyModule_AddObject(m, "StatisticsResponse", (PyObject *)&StatisticsResponseType);

    // Add ZebraSystemTestResponse type to freespace module
    ZebraSystemTestResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ZebraSystemTestResponseType) < 0)
        return;
    Py_INCREF(&ZebraSystemTestResponseType);
    PyModule_AddObject(m, "ZebraSystemTestResponse", (PyObject *)&ZebraSystemTestResponseType);

    // Add ProductIDResponse type to freespace module
    ProductIDResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ProductIDResponseType) < 0)
        return;
    Py_INCREF(&ProductIDResponseType);
    PyModule_AddObject(m, "ProductIDResponse", (PyObject *)&ProductIDResponseType);

    // Add LinkStatus type to freespace module
    LinkStatusType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&LinkStatusType) < 0)
        return;
    Py_INCREF(&LinkStatusType);
    PyModule_AddObject(m, "LinkStatus", (PyObject *)&LinkStatusType);

    // Add AlwaysOnResponse type to freespace module
    AlwaysOnResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&AlwaysOnResponseType) < 0)
        return;
    Py_INCREF(&AlwaysOnResponseType);
    PyModule_AddObject(m, "AlwaysOnResponse", (PyObject *)&AlwaysOnResponseType);

    // Add SPIOperationResponse type to freespace module
    SPIOperationResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&SPIOperationResponseType) < 0)
        return;
    Py_INCREF(&SPIOperationResponseType);
    PyModule_AddObject(m, "SPIOperationResponse", (PyObject *)&SPIOperationResponseType);

    // Add EventReportConfigurationResponse type to freespace module
    EventReportConfigurationResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&EventReportConfigurationResponseType) < 0)
        return;
    Py_INCREF(&EventReportConfigurationResponseType);
    PyModule_AddObject(m, "EventReportConfigurationResponse", (PyObject *)&EventReportConfigurationResponseType);

    // Add EventReport type to freespace module
    EventReportType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&EventReportType) < 0)
        return;
    Py_INCREF(&EventReportType);
    PyModule_AddObject(m, "EventReport", (PyObject *)&EventReportType);

    // Add UnknownCRSNotificationResponse type to freespace module
    UnknownCRSNotificationResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&UnknownCRSNotificationResponseType) < 0)
        return;
    Py_INCREF(&UnknownCRSNotificationResponseType);
    PyModule_AddObject(m, "UnknownCRSNotificationResponse", (PyObject *)&UnknownCRSNotificationResponseType);

    // Add FRSLoopReadResponse type to freespace module
    FRSLoopReadResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSLoopReadResponseType) < 0)
        return;
    Py_INCREF(&FRSLoopReadResponseType);
    PyModule_AddObject(m, "FRSLoopReadResponse", (PyObject *)&FRSLoopReadResponseType);

    // Add FRSLoopWriteResponse type to freespace module
    FRSLoopWriteResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSLoopWriteResponseType) < 0)
        return;
    Py_INCREF(&FRSLoopWriteResponseType);
    PyModule_AddObject(m, "FRSLoopWriteResponse", (PyObject *)&FRSLoopWriteResponseType);

    // Add FRSDongleReadResponse type to freespace module
    FRSDongleReadResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSDongleReadResponseType) < 0)
        return;
    Py_INCREF(&FRSDongleReadResponseType);
    PyModule_AddObject(m, "FRSDongleReadResponse", (PyObject *)&FRSDongleReadResponseType);

    // Add FRSDongleWriteResponse type to freespace module
    FRSDongleWriteResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSDongleWriteResponseType) < 0)
        return;
    Py_INCREF(&FRSDongleWriteResponseType);
    PyModule_AddObject(m, "FRSDongleWriteResponse", (PyObject *)&FRSDongleWriteResponseType);

    // Add FRSEFlashReadResponse type to freespace module
    FRSEFlashReadResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSEFlashReadResponseType) < 0)
        return;
    Py_INCREF(&FRSEFlashReadResponseType);
    PyModule_AddObject(m, "FRSEFlashReadResponse", (PyObject *)&FRSEFlashReadResponseType);

    // Add FRSEFlashWriteResponse type to freespace module
    FRSEFlashWriteResponseType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FRSEFlashWriteResponseType) < 0)
        return;
    Py_INCREF(&FRSEFlashWriteResponseType);
    PyModule_AddObject(m, "FRSEFlashWriteResponse", (PyObject *)&FRSEFlashWriteResponseType);

    // Add FSP2CoprocessorMessage type to freespace module
    FSP2CoprocessorMessageType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&FSP2CoprocessorMessageType) < 0)
        return;
    Py_INCREF(&FSP2CoprocessorMessageType);
    PyModule_AddObject(m, "FSP2CoprocessorMessage", (PyObject *)&FSP2CoprocessorMessageType);

    // Add LoopBootloaderStatus type to freespace module
    LoopBootloaderStatusType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&LoopBootloaderStatusType) < 0)
        return;
    Py_INCREF(&LoopBootloaderStatusType);
    PyModule_AddObject(m, "LoopBootloaderStatus", (PyObject *)&LoopBootloaderStatusType);

    // Add CRSKeepalive type to freespace module
    CRSKeepaliveType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&CRSKeepaliveType) < 0)
        return;
    Py_INCREF(&CRSKeepaliveType);
    PyModule_AddObject(m, "CRSKeepalive", (PyObject *)&CRSKeepaliveType);

    // Add ButtonState type to freespace module
    ButtonStateType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ButtonStateType) < 0)
        return;
    Py_INCREF(&ButtonStateType);
    PyModule_AddObject(m, "ButtonState", (PyObject *)&ButtonStateType);

    // Add ScrollMotion type to freespace module
    ScrollMotionType.tp_new = PyType_GenericNew;
    if (PyType_Ready(&ScrollMotionType) < 0)
        return;
    Py_INCREF(&ScrollMotionType);
    PyModule_AddObject(m, "ScrollMotion", (PyObject *)&ScrollMotionType);
}
